//
//  Copyright (c) 2003 Launchbird Design Systems, Inc.
//  All rights reserved.
//  
//  Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:
//    Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.
//    Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the documentation and/or other materials provided with the distribution.
//  
//  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
//  INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
//  IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY,
//  OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
//  OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
//  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
//  
//  
//  Overview:
//  
//    Performs floating point multiply.
//  
//  Interface:
//  
//  
//  
//    Inputs:
//      a_i : Left operand.
//      b_i : Right operand.
//  
//    Outputs:
//      x_o : Result.
//  
//  Built In Parameters:
//  
//    Exponent Precision = 3
//    Mantissa Precision = 4
//    Total    Precision = 8
//  
//  
//  
//  
//  
//  Generated by Confluence 0.6.3  --  Launchbird Design Systems, Inc.  --  www.launchbird.com
//  
//  Build Date : Fri Aug 22 09:46:58 CDT 2003
//  
//  Interface
//  
//    Build Name    : cf_fp_mul_c_3_4
//    Clock Domains : 
//    Vector Input  : a_i(8)
//    Vector Input  : b_i(8)
//    Vector Output : x_o(8)
//  
//  
//  

`timescale 1 ns / 1 ns

module cf_fp_mul_c_3_4 (a_i, b_i, x_o);
input  [7:0] a_i;
input  [7:0] b_i;
output [7:0] x_o;
wire   [7:0] n1;
cf_fp_mul_c_3_4_1 s1 (a_i, b_i, n1);
assign x_o = n1;
endmodule

module cf_fp_mul_c_3_4_1 (i1, i2, o1);
input  [7:0] i1;
input  [7:0] i2;
output [7:0] o1;
wire   n1;
wire   [3:0] n2;
wire   [3:0] n3;
wire   [3:0] n4;
wire   [8:0] n5;
wire   [8:0] n6;
wire   [8:0] n7;
wire   [3:0] s8_1;
wire   [4:0] s8_2;
wire   [3:0] s9_1;
wire   [5:0] s9_2;
wire   [3:0] s10_1;
wire   [6:0] s10_2;
wire   [3:0] s11_1;
wire   [7:0] s11_2;
wire   s12_1;
wire   s12_2;
wire   s12_3;
wire   s12_4;
wire   s12_5;
wire   [3:0] s12_6;
wire   [9:0] s12_7;
wire   [7:0] s13_1;
assign n1 = s12_7[9];
assign n2 = 4'b0001;
assign n3 = s12_6 + n2;
assign n4 = n1 ? n3 : s12_6;
assign n5 = {s12_7[9],
  s12_7[8],
  s12_7[7],
  s12_7[6],
  s12_7[5],
  s12_7[4],
  s12_7[3],
  s12_7[2],
  s12_7[1]};
assign n6 = {s12_7[8],
  s12_7[7],
  s12_7[6],
  s12_7[5],
  s12_7[4],
  s12_7[3],
  s12_7[2],
  s12_7[1],
  s12_7[0]};
assign n7 = n1 ? n5 : n6;
cf_fp_mul_c_3_4_15 s8 (s9_1, s9_2, s8_1, s8_2);
cf_fp_mul_c_3_4_14 s9 (s10_1, s10_2, s9_1, s9_2);
cf_fp_mul_c_3_4_13 s10 (s11_1, s11_2, s10_1, s10_2);
cf_fp_mul_c_3_4_12 s11 (n4, n7, s11_1, s11_2);
cf_fp_mul_c_3_4_9 s12 (i1, i2, s12_1, s12_2, s12_3, s12_4, s12_5, s12_6, s12_7);
cf_fp_mul_c_3_4_2 s13 (s12_1, s12_2, s12_3, s12_4, s12_5, s8_1, s8_2, s13_1);
assign o1 = s13_1;
endmodule

module cf_fp_mul_c_3_4_2 (i1, i2, i3, i4, i5, i6, i7, o1);
input  i1;
input  i2;
input  i3;
input  i4;
input  i5;
input  [3:0] i6;
input  [4:0] i7;
output [7:0] o1;
wire   [2:0] n1;
wire   [3:0] n2;
wire   [6:0] n3;
wire   [6:0] n4;
wire   [1:0] n5;
wire   [2:0] n6;
wire   [3:0] n7;
wire   [2:0] n8;
wire   [2:0] n9;
wire   [2:0] n10;
wire   [2:0] n11;
wire   [2:0] n12;
wire   [7:0] n13;
wire   [6:0] n14;
wire   [6:0] n15;
wire   [6:0] n16;
wire   [2:0] s17_1;
wire   [6:0] s18_1;
assign n1 = {i6[2],
  i6[1],
  i6[0]};
assign n2 = {i7[3],
  i7[2],
  i7[1],
  i7[0]};
assign n3 = {n1, n2};
assign n4 = 7'b0000000;
assign n5 = {i3, i4};
assign n6 = {i2, n5};
assign n7 = {i1, n6};
assign n8 = 3'b000;
assign n9 = 3'b001;
assign n10 = 3'b010;
assign n11 = 3'b011;
assign n12 = 3'b100;
assign n13 = {i5, s18_1};
assign n14 = 7'b1110000;
assign n15 = 7'b1111111;
assign n16 = 7'b1110111;
cf_fp_mul_c_3_4_4 s17 (n7, n8, n9, n10, n11, n12, s17_1);
cf_fp_mul_c_3_4_3 s18 (n3, n4, s17_1, n14, n15, n16, s18_1);
assign o1 = n13;
endmodule

module cf_fp_mul_c_3_4_3 (i1, i2, i3, i4, i5, i6, o1);
input  [6:0] i1;
input  [6:0] i2;
input  [2:0] i3;
input  [6:0] i4;
input  [6:0] i5;
input  [6:0] i6;
output [6:0] o1;
wire   [1:0] n1;
wire   n2;
wire   [6:0] n3;
wire   [6:0] n4;
wire   n5;
wire   n6;
wire   [6:0] n7;
wire   n8;
wire   [6:0] n9;
assign n1 = {i3[2],
  i3[1]};
assign n2 = i3[0];
assign n3 = n2 ? i2 : i1;
assign n4 = n2 ? i5 : i4;
assign n5 = n1[1];
assign n6 = n1[0];
assign n7 = n6 ? n4 : n3;
assign n8 = n5;
assign n9 = n8 ? i6 : n7;
assign o1 = n9;
endmodule

module cf_fp_mul_c_3_4_4 (i1, i2, i3, i4, i5, i6, o1);
input  [3:0] i1;
input  [2:0] i2;
input  [2:0] i3;
input  [2:0] i4;
input  [2:0] i5;
input  [2:0] i6;
output [2:0] o1;
wire   [3:0] n1;
wire   n2;
wire   [3:0] n3;
wire   n4;
wire   [3:0] n5;
wire   n6;
wire   [2:0] n7;
wire   [2:0] n8;
wire   [2:0] n9;
wire   [2:0] s10_1;
assign n1 = 4'b1000;
assign n2 = i1 == n1;
assign n3 = 4'b1001;
assign n4 = i1 == n3;
assign n5 = 4'b1010;
assign n6 = i1 == n5;
assign n7 = n6 ? i6 : s10_1;
assign n8 = n4 ? i6 : n7;
assign n9 = n2 ? i6 : n8;
cf_fp_mul_c_3_4_5 s10 (i1, i2, i3, i4, i5, i6, s10_1);
assign o1 = n9;
endmodule

module cf_fp_mul_c_3_4_5 (i1, i2, i3, i4, i5, i6, o1);
input  [3:0] i1;
input  [2:0] i2;
input  [2:0] i3;
input  [2:0] i4;
input  [2:0] i5;
input  [2:0] i6;
output [2:0] o1;
wire   [3:0] n1;
wire   n2;
wire   [3:0] n3;
wire   n4;
wire   [3:0] n5;
wire   n6;
wire   [2:0] n7;
wire   [2:0] n8;
wire   [2:0] n9;
wire   [2:0] s10_1;
assign n1 = 4'b1011;
assign n2 = i1 == n1;
assign n3 = 4'b1100;
assign n4 = i1 == n3;
assign n5 = 4'b1101;
assign n6 = i1 == n5;
assign n7 = n6 ? i6 : s10_1;
assign n8 = n4 ? i6 : n7;
assign n9 = n2 ? i6 : n8;
cf_fp_mul_c_3_4_6 s10 (i1, i2, i3, i4, i5, i6, s10_1);
assign o1 = n9;
endmodule

module cf_fp_mul_c_3_4_6 (i1, i2, i3, i4, i5, i6, o1);
input  [3:0] i1;
input  [2:0] i2;
input  [2:0] i3;
input  [2:0] i4;
input  [2:0] i5;
input  [2:0] i6;
output [2:0] o1;
wire   [3:0] n1;
wire   n2;
wire   [3:0] n3;
wire   n4;
wire   [3:0] n5;
wire   n6;
wire   [2:0] n7;
wire   [2:0] n8;
wire   [2:0] n9;
wire   [2:0] s10_1;
assign n1 = 4'b1110;
assign n2 = i1 == n1;
assign n3 = 4'b1111;
assign n4 = i1 == n3;
assign n5 = 4'b0100;
assign n6 = i1 == n5;
assign n7 = n6 ? i5 : s10_1;
assign n8 = n4 ? i6 : n7;
assign n9 = n2 ? i6 : n8;
cf_fp_mul_c_3_4_7 s10 (i1, i2, i3, i4, i5, s10_1);
assign o1 = n9;
endmodule

module cf_fp_mul_c_3_4_7 (i1, i2, i3, i4, i5, o1);
input  [3:0] i1;
input  [2:0] i2;
input  [2:0] i3;
input  [2:0] i4;
input  [2:0] i5;
output [2:0] o1;
wire   [3:0] n1;
wire   n2;
wire   [3:0] n3;
wire   n4;
wire   [3:0] n5;
wire   n6;
wire   [2:0] n7;
wire   [2:0] n8;
wire   [2:0] n9;
wire   [2:0] s10_1;
assign n1 = 4'b0101;
assign n2 = i1 == n1;
assign n3 = 4'b0110;
assign n4 = i1 == n3;
assign n5 = 4'b0111;
assign n6 = i1 == n5;
assign n7 = n6 ? i5 : s10_1;
assign n8 = n4 ? i5 : n7;
assign n9 = n2 ? i5 : n8;
cf_fp_mul_c_3_4_8 s10 (i1, i2, i3, i4, s10_1);
assign o1 = n9;
endmodule

module cf_fp_mul_c_3_4_8 (i1, i2, i3, i4, o1);
input  [3:0] i1;
input  [2:0] i2;
input  [2:0] i3;
input  [2:0] i4;
output [2:0] o1;
wire   [3:0] n1;
wire   n2;
wire   [3:0] n3;
wire   n4;
wire   [3:0] n5;
wire   n6;
wire   [2:0] n7;
wire   [2:0] n8;
wire   [2:0] n9;
assign n1 = 4'b0010;
assign n2 = i1 == n1;
assign n3 = 4'b0011;
assign n4 = i1 == n3;
assign n5 = 4'b0001;
assign n6 = i1 == n5;
assign n7 = n6 ? i3 : i2;
assign n8 = n4 ? i4 : n7;
assign n9 = n2 ? i4 : n8;
assign o1 = n9;
endmodule

module cf_fp_mul_c_3_4_9 (i1, i2, o1, o2, o3, o4, o5, o6, o7);
input  [7:0] i1;
input  [7:0] i2;
output o1;
output o2;
output o3;
output o4;
output o5;
output [3:0] o6;
output [9:0] o7;
wire   n1;
wire   [2:0] n2;
wire   [3:0] n3;
wire   n4;
wire   [2:0] n5;
wire   [3:0] n6;
wire   n7;
wire   n8;
wire   n9;
wire   n10;
wire   n11;
wire   n12;
wire   n13;
wire   n14;
wire   n15;
wire   n16;
wire   [3:0] n17;
wire   n18;
wire   [3:0] n19;
wire   [3:0] n20;
wire   [3:0] n21;
wire   n22;
wire   [4:0] n23;
wire   n24;
wire   [4:0] n25;
wire   [9:0] n26;
wire   [3:0] n27;
wire   s28_1;
wire   s28_2;
wire   s28_3;
wire   s28_4;
wire   s28_5;
wire   s29_1;
wire   s29_2;
wire   s29_3;
wire   s29_4;
wire   s29_5;
assign n1 = i1[7];
assign n2 = {i1[6],
  i1[5],
  i1[4]};
assign n3 = {i1[3],
  i1[2],
  i1[1],
  i1[0]};
assign n4 = i2[7];
assign n5 = {i2[6],
  i2[5],
  i2[4]};
assign n6 = {i2[3],
  i2[2],
  i2[1],
  i2[0]};
assign n7 = s29_2 | s29_1;
assign n8 = s28_2 | s28_1;
assign n9 = n7 | n8;
assign n10 = s29_3 & s28_4;
assign n11 = s29_4 & s28_3;
assign n12 = n10 | n11;
assign n13 = s29_3 | s28_3;
assign n14 = s29_4 | s28_4;
assign n15 = n1 ^ n4;
assign n16 = 1'b0;
assign n17 = {n16, n2};
assign n18 = 1'b0;
assign n19 = {n18, n5};
assign n20 = n17 + n19;
assign n21 = n20 - n27;
assign n22 = ~s29_5;
assign n23 = {n22, n3};
assign n24 = ~s28_5;
assign n25 = {n24, n6};
assign n26 = {{5{1'b0}}, n23} * {{5{1'b0}}, n25};
assign n27 = 4'b0011;
cf_fp_mul_c_3_4_10 s28 (i2, s28_1, s28_2, s28_3, s28_4, s28_5);
cf_fp_mul_c_3_4_10 s29 (i1, s29_1, s29_2, s29_3, s29_4, s29_5);
assign o7 = n26;
assign o6 = n21;
assign o5 = n15;
assign o4 = n14;
assign o3 = n13;
assign o2 = n12;
assign o1 = n9;
endmodule

module cf_fp_mul_c_3_4_10 (i1, o1, o2, o3, o4, o5);
input  [7:0] i1;
output o1;
output o2;
output o3;
output o4;
output o5;
wire   [2:0] n1;
wire   [3:0] n2;
wire   n3;
wire   [1:0] n4;
wire   n5;
wire   n6;
wire   n7;
wire   n8;
wire   n9;
wire   n10;
wire   n11;
wire   n12;
wire   n13;
wire   n14;
wire   n15;
wire   n16;
wire   n17;
wire   n18;
wire   n19;
wire   n20;
wire   s21_1;
wire   s22_1;
assign n1 = {i1[6],
  i1[5],
  i1[4]};
assign n2 = {i1[3],
  i1[2],
  i1[1],
  i1[0]};
assign n3 = n1[2];
assign n4 = {n1[1],
  n1[0]};
assign n5 = n4[1];
assign n6 = n4[0];
assign n7 = n6;
assign n8 = n3 & n5;
assign n9 = n8 & n7;
assign n10 = n2[3];
assign n11 = n9 & n10;
assign n12 = n2[3];
assign n13 = ~n12;
assign n14 = n9 & n13;
assign n15 = ~s21_1;
assign n16 = n14 & n15;
assign n17 = n9 & s21_1;
assign n18 = s22_1 & s21_1;
assign n19 = ~s21_1;
assign n20 = s22_1 & n19;
cf_fp_mul_c_3_4_16 s21 (n2, s21_1);
cf_fp_mul_c_3_4_11 s22 (n1, s22_1);
assign o5 = n20;
assign o4 = n18;
assign o3 = n17;
assign o2 = n16;
assign o1 = n11;
endmodule

module cf_fp_mul_c_3_4_11 (i1, o1);
input  [2:0] i1;
output o1;
wire   n1;
wire   [1:0] n2;
wire   n3;
wire   n4;
wire   n5;
wire   n6;
wire   n7;
wire   n8;
assign n1 = i1[2];
assign n2 = {i1[1],
  i1[0]};
assign n3 = n2[1];
assign n4 = n2[0];
assign n5 = n4;
assign n6 = n1 | n3;
assign n7 = n6 | n5;
assign n8 = ~n7;
assign o1 = n8;
endmodule

module cf_fp_mul_c_3_4_12 (i1, i2, o1, o2);
input  [3:0] i1;
input  [8:0] i2;
output [3:0] o1;
output [7:0] o2;
wire   n1;
wire   n2;
wire   n3;
wire   [3:0] n4;
wire   [3:0] n5;
wire   [3:0] n6;
wire   [7:0] n7;
wire   [7:0] n8;
wire   [7:0] n9;
wire   s10_1;
assign n1 = i2[8];
assign n2 = n1 | s10_1;
assign n3 = ~n2;
assign n4 = 4'b0001;
assign n5 = i1 - n4;
assign n6 = n3 ? n5 : i1;
assign n7 = {i2[7],
  i2[6],
  i2[5],
  i2[4],
  i2[3],
  i2[2],
  i2[1],
  i2[0]};
assign n8 = {i2[8],
  i2[7],
  i2[6],
  i2[5],
  i2[4],
  i2[3],
  i2[2],
  i2[1]};
assign n9 = n3 ? n7 : n8;
cf_fp_mul_c_3_4_16 s10 (i1, s10_1);
assign o2 = n9;
assign o1 = n6;
endmodule

module cf_fp_mul_c_3_4_13 (i1, i2, o1, o2);
input  [3:0] i1;
input  [7:0] i2;
output [3:0] o1;
output [6:0] o2;
wire   n1;
wire   n2;
wire   n3;
wire   [3:0] n4;
wire   [3:0] n5;
wire   [3:0] n6;
wire   [6:0] n7;
wire   [6:0] n8;
wire   [6:0] n9;
wire   s10_1;
assign n1 = i2[7];
assign n2 = n1 | s10_1;
assign n3 = ~n2;
assign n4 = 4'b0001;
assign n5 = i1 - n4;
assign n6 = n3 ? n5 : i1;
assign n7 = {i2[6],
  i2[5],
  i2[4],
  i2[3],
  i2[2],
  i2[1],
  i2[0]};
assign n8 = {i2[7],
  i2[6],
  i2[5],
  i2[4],
  i2[3],
  i2[2],
  i2[1]};
assign n9 = n3 ? n7 : n8;
cf_fp_mul_c_3_4_16 s10 (i1, s10_1);
assign o2 = n9;
assign o1 = n6;
endmodule

module cf_fp_mul_c_3_4_14 (i1, i2, o1, o2);
input  [3:0] i1;
input  [6:0] i2;
output [3:0] o1;
output [5:0] o2;
wire   n1;
wire   n2;
wire   n3;
wire   [3:0] n4;
wire   [3:0] n5;
wire   [3:0] n6;
wire   [5:0] n7;
wire   [5:0] n8;
wire   [5:0] n9;
wire   s10_1;
assign n1 = i2[6];
assign n2 = n1 | s10_1;
assign n3 = ~n2;
assign n4 = 4'b0001;
assign n5 = i1 - n4;
assign n6 = n3 ? n5 : i1;
assign n7 = {i2[5],
  i2[4],
  i2[3],
  i2[2],
  i2[1],
  i2[0]};
assign n8 = {i2[6],
  i2[5],
  i2[4],
  i2[3],
  i2[2],
  i2[1]};
assign n9 = n3 ? n7 : n8;
cf_fp_mul_c_3_4_16 s10 (i1, s10_1);
assign o2 = n9;
assign o1 = n6;
endmodule

module cf_fp_mul_c_3_4_15 (i1, i2, o1, o2);
input  [3:0] i1;
input  [5:0] i2;
output [3:0] o1;
output [4:0] o2;
wire   n1;
wire   n2;
wire   n3;
wire   [3:0] n4;
wire   [3:0] n5;
wire   [3:0] n6;
wire   [4:0] n7;
wire   [4:0] n8;
wire   [4:0] n9;
wire   s10_1;
assign n1 = i2[5];
assign n2 = n1 | s10_1;
assign n3 = ~n2;
assign n4 = 4'b0001;
assign n5 = i1 - n4;
assign n6 = n3 ? n5 : i1;
assign n7 = {i2[4],
  i2[3],
  i2[2],
  i2[1],
  i2[0]};
assign n8 = {i2[5],
  i2[4],
  i2[3],
  i2[2],
  i2[1]};
assign n9 = n3 ? n7 : n8;
cf_fp_mul_c_3_4_16 s10 (i1, s10_1);
assign o2 = n9;
assign o1 = n6;
endmodule

module cf_fp_mul_c_3_4_16 (i1, o1);
input  [3:0] i1;
output o1;
wire   n1;
wire   [2:0] n2;
wire   n3;
wire   [1:0] n4;
wire   n5;
wire   n6;
wire   n7;
wire   n8;
wire   n9;
wire   n10;
wire   n11;
assign n1 = i1[3];
assign n2 = {i1[2],
  i1[1],
  i1[0]};
assign n3 = n2[2];
assign n4 = {n2[1],
  n2[0]};
assign n5 = n4[1];
assign n6 = n4[0];
assign n7 = n6;
assign n8 = n1 | n3;
assign n9 = n5 | n7;
assign n10 = n8 | n9;
assign n11 = ~n10;
assign o1 = n11;
endmodule

