--
--  Copyright (c) 2003 Launchbird Design Systems, Inc.
--  All rights reserved.
--  
--  Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:
--    Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.
--    Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the documentation and/or other materials provided with the distribution.
--  
--  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
--  INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
--  IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY,
--  OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
--  OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
--  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
--  
--  
--  Overview:
--  
--    Performs floating point multiply.
--  
--  Interface:
--  
--    Synchronization:
--      clock_c  : Clock input.
--  
--    Inputs:
--      a_i : Left operand.
--      b_i : Right operand.
--  
--    Outputs:
--      x_o : Result.
--  
--  Built In Parameters:
--  
--    Exponent Precision = 5
--    Mantissa Precision = 10
--    Total    Precision = 16
--    Pipeline Latency   = 14 clock cycles
--  
--  
--  
--  
--  Generated by Confluence 0.6.3  --  Launchbird Design Systems, Inc.  --  www.launchbird.com
--  
--  Build Date : Fri Aug 22 09:47:04 CDT 2003
--  
--  Interface
--  
--    Build Name    : cf_fp_mul_p_5_10
--    Clock Domains : clock_c  
--    Vector Input  : a_i(16)
--    Vector Input  : b_i(16)
--    Vector Output : x_o(16)
--  
--  
--  

library ieee;
use ieee.std_logic_1164.all;
use ieee.numeric_std.all;
entity cf_fp_mul_p_5_10_35 is
port (
i1 : in  unsigned(3 downto 0);
i2 : in  unsigned(2 downto 0);
i3 : in  unsigned(2 downto 0);
i4 : in  unsigned(2 downto 0);
o1 : out unsigned(2 downto 0));
end entity cf_fp_mul_p_5_10_35;
architecture rtl of cf_fp_mul_p_5_10_35 is
signal n1 : unsigned(3 downto 0);
signal n2 : unsigned(0 downto 0);
signal n3 : unsigned(3 downto 0);
signal n4 : unsigned(0 downto 0);
signal n5 : unsigned(3 downto 0);
signal n6 : unsigned(0 downto 0);
signal n7 : unsigned(2 downto 0);
signal n8 : unsigned(2 downto 0);
signal n9 : unsigned(2 downto 0);
begin
n1 <= "0010";
n2 <= "1" when i1 = n1 else "0";
n3 <= "0011";
n4 <= "1" when i1 = n3 else "0";
n5 <= "0001";
n6 <= "1" when i1 = n5 else "0";
n7 <= i3 when n6 = "1" else i2;
n8 <= i4 when n4 = "1" else n7;
n9 <= i4 when n2 = "1" else n8;
o1 <= n9;
end architecture rtl;

library ieee;
use ieee.std_logic_1164.all;
use ieee.numeric_std.all;
entity cf_fp_mul_p_5_10_34 is
port (
i1 : in  unsigned(3 downto 0);
i2 : in  unsigned(2 downto 0);
i3 : in  unsigned(2 downto 0);
i4 : in  unsigned(2 downto 0);
i5 : in  unsigned(2 downto 0);
o1 : out unsigned(2 downto 0));
end entity cf_fp_mul_p_5_10_34;
architecture rtl of cf_fp_mul_p_5_10_34 is
signal n1 : unsigned(3 downto 0);
signal n2 : unsigned(0 downto 0);
signal n3 : unsigned(3 downto 0);
signal n4 : unsigned(0 downto 0);
signal n5 : unsigned(3 downto 0);
signal n6 : unsigned(0 downto 0);
signal n7 : unsigned(2 downto 0);
signal n8 : unsigned(2 downto 0);
signal n9 : unsigned(2 downto 0);
signal s10_1 : unsigned(2 downto 0);
component cf_fp_mul_p_5_10_35 is
port (
i1 : in  unsigned(3 downto 0);
i2 : in  unsigned(2 downto 0);
i3 : in  unsigned(2 downto 0);
i4 : in  unsigned(2 downto 0);
o1 : out unsigned(2 downto 0));
end component cf_fp_mul_p_5_10_35;
begin
n1 <= "0101";
n2 <= "1" when i1 = n1 else "0";
n3 <= "0110";
n4 <= "1" when i1 = n3 else "0";
n5 <= "0111";
n6 <= "1" when i1 = n5 else "0";
n7 <= i5 when n6 = "1" else s10_1;
n8 <= i5 when n4 = "1" else n7;
n9 <= i5 when n2 = "1" else n8;
s10 : cf_fp_mul_p_5_10_35 port map (i1, i2, i3, i4, s10_1);
o1 <= n9;
end architecture rtl;

library ieee;
use ieee.std_logic_1164.all;
use ieee.numeric_std.all;
entity cf_fp_mul_p_5_10_33 is
port (
i1 : in  unsigned(3 downto 0);
i2 : in  unsigned(2 downto 0);
i3 : in  unsigned(2 downto 0);
i4 : in  unsigned(2 downto 0);
i5 : in  unsigned(2 downto 0);
i6 : in  unsigned(2 downto 0);
o1 : out unsigned(2 downto 0));
end entity cf_fp_mul_p_5_10_33;
architecture rtl of cf_fp_mul_p_5_10_33 is
signal n1 : unsigned(3 downto 0);
signal n2 : unsigned(0 downto 0);
signal n3 : unsigned(3 downto 0);
signal n4 : unsigned(0 downto 0);
signal n5 : unsigned(3 downto 0);
signal n6 : unsigned(0 downto 0);
signal n7 : unsigned(2 downto 0);
signal n8 : unsigned(2 downto 0);
signal n9 : unsigned(2 downto 0);
signal s10_1 : unsigned(2 downto 0);
component cf_fp_mul_p_5_10_34 is
port (
i1 : in  unsigned(3 downto 0);
i2 : in  unsigned(2 downto 0);
i3 : in  unsigned(2 downto 0);
i4 : in  unsigned(2 downto 0);
i5 : in  unsigned(2 downto 0);
o1 : out unsigned(2 downto 0));
end component cf_fp_mul_p_5_10_34;
begin
n1 <= "1110";
n2 <= "1" when i1 = n1 else "0";
n3 <= "1111";
n4 <= "1" when i1 = n3 else "0";
n5 <= "0100";
n6 <= "1" when i1 = n5 else "0";
n7 <= i5 when n6 = "1" else s10_1;
n8 <= i6 when n4 = "1" else n7;
n9 <= i6 when n2 = "1" else n8;
s10 : cf_fp_mul_p_5_10_34 port map (i1, i2, i3, i4, i5, s10_1);
o1 <= n9;
end architecture rtl;

library ieee;
use ieee.std_logic_1164.all;
use ieee.numeric_std.all;
entity cf_fp_mul_p_5_10_32 is
port (
i1 : in  unsigned(3 downto 0);
i2 : in  unsigned(2 downto 0);
i3 : in  unsigned(2 downto 0);
i4 : in  unsigned(2 downto 0);
i5 : in  unsigned(2 downto 0);
i6 : in  unsigned(2 downto 0);
o1 : out unsigned(2 downto 0));
end entity cf_fp_mul_p_5_10_32;
architecture rtl of cf_fp_mul_p_5_10_32 is
signal n1 : unsigned(3 downto 0);
signal n2 : unsigned(0 downto 0);
signal n3 : unsigned(3 downto 0);
signal n4 : unsigned(0 downto 0);
signal n5 : unsigned(3 downto 0);
signal n6 : unsigned(0 downto 0);
signal n7 : unsigned(2 downto 0);
signal n8 : unsigned(2 downto 0);
signal n9 : unsigned(2 downto 0);
signal s10_1 : unsigned(2 downto 0);
component cf_fp_mul_p_5_10_33 is
port (
i1 : in  unsigned(3 downto 0);
i2 : in  unsigned(2 downto 0);
i3 : in  unsigned(2 downto 0);
i4 : in  unsigned(2 downto 0);
i5 : in  unsigned(2 downto 0);
i6 : in  unsigned(2 downto 0);
o1 : out unsigned(2 downto 0));
end component cf_fp_mul_p_5_10_33;
begin
n1 <= "1011";
n2 <= "1" when i1 = n1 else "0";
n3 <= "1100";
n4 <= "1" when i1 = n3 else "0";
n5 <= "1101";
n6 <= "1" when i1 = n5 else "0";
n7 <= i6 when n6 = "1" else s10_1;
n8 <= i6 when n4 = "1" else n7;
n9 <= i6 when n2 = "1" else n8;
s10 : cf_fp_mul_p_5_10_33 port map (i1, i2, i3, i4, i5, i6, s10_1);
o1 <= n9;
end architecture rtl;

library ieee;
use ieee.std_logic_1164.all;
use ieee.numeric_std.all;
entity cf_fp_mul_p_5_10_31 is
port (
i1 : in  unsigned(3 downto 0);
i2 : in  unsigned(2 downto 0);
i3 : in  unsigned(2 downto 0);
i4 : in  unsigned(2 downto 0);
i5 : in  unsigned(2 downto 0);
i6 : in  unsigned(2 downto 0);
o1 : out unsigned(2 downto 0));
end entity cf_fp_mul_p_5_10_31;
architecture rtl of cf_fp_mul_p_5_10_31 is
signal n1 : unsigned(3 downto 0);
signal n2 : unsigned(0 downto 0);
signal n3 : unsigned(3 downto 0);
signal n4 : unsigned(0 downto 0);
signal n5 : unsigned(3 downto 0);
signal n6 : unsigned(0 downto 0);
signal n7 : unsigned(2 downto 0);
signal n8 : unsigned(2 downto 0);
signal n9 : unsigned(2 downto 0);
signal s10_1 : unsigned(2 downto 0);
component cf_fp_mul_p_5_10_32 is
port (
i1 : in  unsigned(3 downto 0);
i2 : in  unsigned(2 downto 0);
i3 : in  unsigned(2 downto 0);
i4 : in  unsigned(2 downto 0);
i5 : in  unsigned(2 downto 0);
i6 : in  unsigned(2 downto 0);
o1 : out unsigned(2 downto 0));
end component cf_fp_mul_p_5_10_32;
begin
n1 <= "1000";
n2 <= "1" when i1 = n1 else "0";
n3 <= "1001";
n4 <= "1" when i1 = n3 else "0";
n5 <= "1010";
n6 <= "1" when i1 = n5 else "0";
n7 <= i6 when n6 = "1" else s10_1;
n8 <= i6 when n4 = "1" else n7;
n9 <= i6 when n2 = "1" else n8;
s10 : cf_fp_mul_p_5_10_32 port map (i1, i2, i3, i4, i5, i6, s10_1);
o1 <= n9;
end architecture rtl;

library ieee;
use ieee.std_logic_1164.all;
use ieee.numeric_std.all;
entity cf_fp_mul_p_5_10_30 is
port (
i1 : in  unsigned(14 downto 0);
i2 : in  unsigned(14 downto 0);
i3 : in  unsigned(2 downto 0);
i4 : in  unsigned(14 downto 0);
i5 : in  unsigned(14 downto 0);
i6 : in  unsigned(14 downto 0);
o1 : out unsigned(14 downto 0));
end entity cf_fp_mul_p_5_10_30;
architecture rtl of cf_fp_mul_p_5_10_30 is
signal n1 : unsigned(1 downto 0);
signal n2 : unsigned(0 downto 0);
signal n3 : unsigned(14 downto 0);
signal n4 : unsigned(14 downto 0);
signal n5 : unsigned(0 downto 0);
signal n6 : unsigned(0 downto 0);
signal n7 : unsigned(14 downto 0);
signal n8 : unsigned(0 downto 0);
signal n9 : unsigned(14 downto 0);
begin
n1 <= i3(2 downto 2) &
  i3(1 downto 1);
n2 <= i3(0 downto 0);
n3 <= i2 when n2 = "1" else i1;
n4 <= i5 when n2 = "1" else i4;
n5 <= n1(1 downto 1);
n6 <= n1(0 downto 0);
n7 <= n4 when n6 = "1" else n3;
n8 <= n5(0 downto 0);
n9 <= i6 when n8 = "1" else n7;
o1 <= n9;
end architecture rtl;

library ieee;
use ieee.std_logic_1164.all;
use ieee.numeric_std.all;
entity cf_fp_mul_p_5_10_29 is
port (
i1 : in  unsigned(0 downto 0);
i2 : in  unsigned(0 downto 0);
i3 : in  unsigned(0 downto 0);
i4 : in  unsigned(0 downto 0);
i5 : in  unsigned(0 downto 0);
i6 : in  unsigned(5 downto 0);
i7 : in  unsigned(10 downto 0);
o1 : out unsigned(15 downto 0));
end entity cf_fp_mul_p_5_10_29;
architecture rtl of cf_fp_mul_p_5_10_29 is
signal n1 : unsigned(4 downto 0);
signal n2 : unsigned(9 downto 0);
signal n3 : unsigned(14 downto 0);
signal n4 : unsigned(14 downto 0);
signal n5 : unsigned(1 downto 0);
signal n6 : unsigned(2 downto 0);
signal n7 : unsigned(3 downto 0);
signal n8 : unsigned(2 downto 0);
signal n9 : unsigned(2 downto 0);
signal n10 : unsigned(2 downto 0);
signal n11 : unsigned(2 downto 0);
signal n12 : unsigned(2 downto 0);
signal n13 : unsigned(15 downto 0);
signal n14 : unsigned(14 downto 0);
signal n15 : unsigned(14 downto 0);
signal n16 : unsigned(14 downto 0);
signal s17_1 : unsigned(2 downto 0);
signal s18_1 : unsigned(14 downto 0);
component cf_fp_mul_p_5_10_31 is
port (
i1 : in  unsigned(3 downto 0);
i2 : in  unsigned(2 downto 0);
i3 : in  unsigned(2 downto 0);
i4 : in  unsigned(2 downto 0);
i5 : in  unsigned(2 downto 0);
i6 : in  unsigned(2 downto 0);
o1 : out unsigned(2 downto 0));
end component cf_fp_mul_p_5_10_31;
component cf_fp_mul_p_5_10_30 is
port (
i1 : in  unsigned(14 downto 0);
i2 : in  unsigned(14 downto 0);
i3 : in  unsigned(2 downto 0);
i4 : in  unsigned(14 downto 0);
i5 : in  unsigned(14 downto 0);
i6 : in  unsigned(14 downto 0);
o1 : out unsigned(14 downto 0));
end component cf_fp_mul_p_5_10_30;
begin
n1 <= i6(4 downto 4) &
  i6(3 downto 3) &
  i6(2 downto 2) &
  i6(1 downto 1) &
  i6(0 downto 0);
n2 <= i7(9 downto 9) &
  i7(8 downto 8) &
  i7(7 downto 7) &
  i7(6 downto 6) &
  i7(5 downto 5) &
  i7(4 downto 4) &
  i7(3 downto 3) &
  i7(2 downto 2) &
  i7(1 downto 1) &
  i7(0 downto 0);
n3 <= n1 & n2;
n4 <= "000000000000000";
n5 <= i3 & i4;
n6 <= i2 & n5;
n7 <= i1 & n6;
n8 <= "000";
n9 <= "001";
n10 <= "010";
n11 <= "011";
n12 <= "100";
n13 <= i5 & s18_1;
n14 <= "111110000000000";
n15 <= "111111111111111";
n16 <= "111110111111111";
s17 : cf_fp_mul_p_5_10_31 port map (n7, n8, n9, n10, n11, n12, s17_1);
s18 : cf_fp_mul_p_5_10_30 port map (n3, n4, s17_1, n14, n15, n16, s18_1);
o1 <= n13;
end architecture rtl;

library ieee;
use ieee.std_logic_1164.all;
use ieee.numeric_std.all;
entity cf_fp_mul_p_5_10_28 is
port (
i1 : in  unsigned(4 downto 0);
o1 : out unsigned(0 downto 0);
o2 : out unsigned(0 downto 0);
o3 : out unsigned(0 downto 0);
o4 : out unsigned(0 downto 0);
o5 : out unsigned(0 downto 0));
end entity cf_fp_mul_p_5_10_28;
architecture rtl of cf_fp_mul_p_5_10_28 is
signal n1 : unsigned(0 downto 0);
signal n2 : unsigned(3 downto 0);
signal n3 : unsigned(0 downto 0);
signal n4 : unsigned(2 downto 0);
signal n5 : unsigned(0 downto 0);
signal n6 : unsigned(1 downto 0);
signal n7 : unsigned(0 downto 0);
signal n8 : unsigned(0 downto 0);
signal n9 : unsigned(0 downto 0);
begin
n1 <= i1(4 downto 4);
n2 <= i1(3 downto 3) &
  i1(2 downto 2) &
  i1(1 downto 1) &
  i1(0 downto 0);
n3 <= n2(3 downto 3);
n4 <= n2(2 downto 2) &
  n2(1 downto 1) &
  n2(0 downto 0);
n5 <= n4(2 downto 2);
n6 <= n4(1 downto 1) &
  n4(0 downto 0);
n7 <= n6(1 downto 1);
n8 <= n6(0 downto 0);
n9 <= n8(0 downto 0);
o5 <= n9;
o4 <= n7;
o3 <= n5;
o2 <= n3;
o1 <= n1;
end architecture rtl;

library ieee;
use ieee.std_logic_1164.all;
use ieee.numeric_std.all;
entity cf_fp_mul_p_5_10_27 is
port (
i1 : in  unsigned(8 downto 0);
o1 : out unsigned(0 downto 0);
o2 : out unsigned(0 downto 0);
o3 : out unsigned(0 downto 0);
o4 : out unsigned(0 downto 0);
o5 : out unsigned(0 downto 0);
o6 : out unsigned(0 downto 0);
o7 : out unsigned(0 downto 0);
o8 : out unsigned(0 downto 0);
o9 : out unsigned(0 downto 0));
end entity cf_fp_mul_p_5_10_27;
architecture rtl of cf_fp_mul_p_5_10_27 is
signal n1 : unsigned(0 downto 0);
signal n2 : unsigned(7 downto 0);
signal n3 : unsigned(0 downto 0);
signal n4 : unsigned(6 downto 0);
signal n5 : unsigned(0 downto 0);
signal n6 : unsigned(5 downto 0);
signal n7 : unsigned(0 downto 0);
signal n8 : unsigned(4 downto 0);
signal s9_1 : unsigned(0 downto 0);
signal s9_2 : unsigned(0 downto 0);
signal s9_3 : unsigned(0 downto 0);
signal s9_4 : unsigned(0 downto 0);
signal s9_5 : unsigned(0 downto 0);
component cf_fp_mul_p_5_10_28 is
port (
i1 : in  unsigned(4 downto 0);
o1 : out unsigned(0 downto 0);
o2 : out unsigned(0 downto 0);
o3 : out unsigned(0 downto 0);
o4 : out unsigned(0 downto 0);
o5 : out unsigned(0 downto 0));
end component cf_fp_mul_p_5_10_28;
begin
n1 <= i1(8 downto 8);
n2 <= i1(7 downto 7) &
  i1(6 downto 6) &
  i1(5 downto 5) &
  i1(4 downto 4) &
  i1(3 downto 3) &
  i1(2 downto 2) &
  i1(1 downto 1) &
  i1(0 downto 0);
n3 <= n2(7 downto 7);
n4 <= n2(6 downto 6) &
  n2(5 downto 5) &
  n2(4 downto 4) &
  n2(3 downto 3) &
  n2(2 downto 2) &
  n2(1 downto 1) &
  n2(0 downto 0);
n5 <= n4(6 downto 6);
n6 <= n4(5 downto 5) &
  n4(4 downto 4) &
  n4(3 downto 3) &
  n4(2 downto 2) &
  n4(1 downto 1) &
  n4(0 downto 0);
n7 <= n6(5 downto 5);
n8 <= n6(4 downto 4) &
  n6(3 downto 3) &
  n6(2 downto 2) &
  n6(1 downto 1) &
  n6(0 downto 0);
s9 : cf_fp_mul_p_5_10_28 port map (n8, s9_1, s9_2, s9_3, s9_4, s9_5);
o9 <= s9_5;
o8 <= s9_4;
o7 <= s9_3;
o6 <= s9_2;
o5 <= s9_1;
o4 <= n7;
o3 <= n5;
o2 <= n3;
o1 <= n1;
end architecture rtl;

library ieee;
use ieee.std_logic_1164.all;
use ieee.numeric_std.all;
entity cf_fp_mul_p_5_10_26 is
port (
i1 : in  unsigned(0 downto 0);
i2 : in  unsigned(0 downto 0);
i3 : in  unsigned(0 downto 0);
i4 : in  unsigned(0 downto 0);
i5 : in  unsigned(0 downto 0);
i6 : in  unsigned(0 downto 0);
i7 : in  unsigned(0 downto 0);
i8 : in  unsigned(0 downto 0);
i9 : in  unsigned(0 downto 0);
i10 : in  unsigned(0 downto 0);
o1 : out unsigned(0 downto 0));
end entity cf_fp_mul_p_5_10_26;
architecture rtl of cf_fp_mul_p_5_10_26 is
signal n1 : unsigned(0 downto 0);
signal n2 : unsigned(0 downto 0);
signal n3 : unsigned(0 downto 0);
signal n4 : unsigned(0 downto 0);
signal n5 : unsigned(0 downto 0);
signal n6 : unsigned(0 downto 0);
signal n7 : unsigned(0 downto 0);
signal n8 : unsigned(0 downto 0);
signal n9 : unsigned(0 downto 0);
begin
n1 <= i1 or i2;
n2 <= i3 or i4;
n3 <= i5 or i6;
n4 <= i7 or i8;
n5 <= i9 or i10;
n6 <= n1 or n2;
n7 <= n3 or n4;
n8 <= n6 or n7;
n9 <= n8 or n5;
o1 <= n9;
end architecture rtl;

library ieee;
use ieee.std_logic_1164.all;
use ieee.numeric_std.all;
entity cf_fp_mul_p_5_10_25 is
port (
i1 : in  unsigned(15 downto 0);
o1 : out unsigned(0 downto 0);
o2 : out unsigned(0 downto 0);
o3 : out unsigned(0 downto 0);
o4 : out unsigned(0 downto 0);
o5 : out unsigned(0 downto 0));
end entity cf_fp_mul_p_5_10_25;
architecture rtl of cf_fp_mul_p_5_10_25 is
signal n1 : unsigned(4 downto 0);
signal n2 : unsigned(9 downto 0);
signal n3 : unsigned(0 downto 0);
signal n4 : unsigned(0 downto 0);
signal n5 : unsigned(0 downto 0);
signal n6 : unsigned(0 downto 0);
signal n7 : unsigned(0 downto 0);
signal n8 : unsigned(0 downto 0);
signal n9 : unsigned(0 downto 0);
signal n10 : unsigned(0 downto 0);
signal n11 : unsigned(0 downto 0);
signal n12 : unsigned(0 downto 0);
signal n13 : unsigned(8 downto 0);
signal n14 : unsigned(0 downto 0);
signal n15 : unsigned(0 downto 0);
signal n16 : unsigned(0 downto 0);
signal n17 : unsigned(0 downto 0);
signal n18 : unsigned(0 downto 0);
signal n19 : unsigned(0 downto 0);
signal n20 : unsigned(0 downto 0);
signal n21 : unsigned(0 downto 0);
signal n22 : unsigned(0 downto 0);
signal n23 : unsigned(0 downto 0);
signal n24 : unsigned(0 downto 0);
signal n25 : unsigned(0 downto 0);
signal s26_1 : unsigned(0 downto 0);
signal s26_2 : unsigned(0 downto 0);
signal s26_3 : unsigned(0 downto 0);
signal s26_4 : unsigned(0 downto 0);
signal s26_5 : unsigned(0 downto 0);
signal s27_1 : unsigned(0 downto 0);
signal s27_2 : unsigned(0 downto 0);
signal s27_3 : unsigned(0 downto 0);
signal s27_4 : unsigned(0 downto 0);
signal s27_5 : unsigned(0 downto 0);
signal s28_1 : unsigned(0 downto 0);
signal s28_2 : unsigned(0 downto 0);
signal s28_3 : unsigned(0 downto 0);
signal s28_4 : unsigned(0 downto 0);
signal s28_5 : unsigned(0 downto 0);
signal s28_6 : unsigned(0 downto 0);
signal s28_7 : unsigned(0 downto 0);
signal s28_8 : unsigned(0 downto 0);
signal s28_9 : unsigned(0 downto 0);
signal s29_1 : unsigned(0 downto 0);
component cf_fp_mul_p_5_10_28 is
port (
i1 : in  unsigned(4 downto 0);
o1 : out unsigned(0 downto 0);
o2 : out unsigned(0 downto 0);
o3 : out unsigned(0 downto 0);
o4 : out unsigned(0 downto 0);
o5 : out unsigned(0 downto 0));
end component cf_fp_mul_p_5_10_28;
component cf_fp_mul_p_5_10_27 is
port (
i1 : in  unsigned(8 downto 0);
o1 : out unsigned(0 downto 0);
o2 : out unsigned(0 downto 0);
o3 : out unsigned(0 downto 0);
o4 : out unsigned(0 downto 0);
o5 : out unsigned(0 downto 0);
o6 : out unsigned(0 downto 0);
o7 : out unsigned(0 downto 0);
o8 : out unsigned(0 downto 0);
o9 : out unsigned(0 downto 0));
end component cf_fp_mul_p_5_10_27;
component cf_fp_mul_p_5_10_26 is
port (
i1 : in  unsigned(0 downto 0);
i2 : in  unsigned(0 downto 0);
i3 : in  unsigned(0 downto 0);
i4 : in  unsigned(0 downto 0);
i5 : in  unsigned(0 downto 0);
i6 : in  unsigned(0 downto 0);
i7 : in  unsigned(0 downto 0);
i8 : in  unsigned(0 downto 0);
i9 : in  unsigned(0 downto 0);
i10 : in  unsigned(0 downto 0);
o1 : out unsigned(0 downto 0));
end component cf_fp_mul_p_5_10_26;
begin
n1 <= i1(14 downto 14) &
  i1(13 downto 13) &
  i1(12 downto 12) &
  i1(11 downto 11) &
  i1(10 downto 10);
n2 <= i1(9 downto 9) &
  i1(8 downto 8) &
  i1(7 downto 7) &
  i1(6 downto 6) &
  i1(5 downto 5) &
  i1(4 downto 4) &
  i1(3 downto 3) &
  i1(2 downto 2) &
  i1(1 downto 1) &
  i1(0 downto 0);
n3 <= s26_1 and s26_2;
n4 <= s26_3 and s26_4;
n5 <= n3 and n4;
n6 <= n5 and s26_5;
n7 <= s27_1 or s27_2;
n8 <= s27_3 or s27_4;
n9 <= n7 or n8;
n10 <= n9 or s27_5;
n11 <= not n10;
n12 <= n2(9 downto 9);
n13 <= n2(8 downto 8) &
  n2(7 downto 7) &
  n2(6 downto 6) &
  n2(5 downto 5) &
  n2(4 downto 4) &
  n2(3 downto 3) &
  n2(2 downto 2) &
  n2(1 downto 1) &
  n2(0 downto 0);
n14 <= not s29_1;
n15 <= n2(9 downto 9);
n16 <= n6 and n15;
n17 <= n2(9 downto 9);
n18 <= not n17;
n19 <= n6 and n18;
n20 <= not n14;
n21 <= n19 and n20;
n22 <= n6 and n14;
n23 <= n11 and n14;
n24 <= not n14;
n25 <= n11 and n24;
s26 : cf_fp_mul_p_5_10_28 port map (n1, s26_1, s26_2, s26_3, s26_4, s26_5);
s27 : cf_fp_mul_p_5_10_28 port map (n1, s27_1, s27_2, s27_3, s27_4, s27_5);
s28 : cf_fp_mul_p_5_10_27 port map (n13, s28_1, s28_2, s28_3, s28_4, s28_5, s28_6, s28_7, s28_8, s28_9);
s29 : cf_fp_mul_p_5_10_26 port map (n12, s28_1, s28_2, s28_3, s28_4, s28_5, s28_6, s28_7, s28_8, s28_9, s29_1);
o5 <= n25;
o4 <= n23;
o3 <= n22;
o2 <= n21;
o1 <= n16;
end architecture rtl;

library ieee;
use ieee.std_logic_1164.all;
use ieee.numeric_std.all;
entity cf_fp_mul_p_5_10_24 is
port (
i1 : in  unsigned(15 downto 0);
i2 : in  unsigned(15 downto 0);
o1 : out unsigned(0 downto 0);
o2 : out unsigned(0 downto 0);
o3 : out unsigned(0 downto 0);
o4 : out unsigned(0 downto 0);
o5 : out unsigned(0 downto 0);
o6 : out unsigned(5 downto 0);
o7 : out unsigned(21 downto 0));
end entity cf_fp_mul_p_5_10_24;
architecture rtl of cf_fp_mul_p_5_10_24 is
signal n1 : unsigned(0 downto 0);
signal n2 : unsigned(4 downto 0);
signal n3 : unsigned(9 downto 0);
signal n4 : unsigned(0 downto 0);
signal n5 : unsigned(4 downto 0);
signal n6 : unsigned(9 downto 0);
signal n7 : unsigned(0 downto 0);
signal n8 : unsigned(0 downto 0);
signal n9 : unsigned(0 downto 0);
signal n10 : unsigned(0 downto 0);
signal n11 : unsigned(0 downto 0);
signal n12 : unsigned(0 downto 0);
signal n13 : unsigned(0 downto 0);
signal n14 : unsigned(0 downto 0);
signal n15 : unsigned(0 downto 0);
signal n16 : unsigned(0 downto 0);
signal n17 : unsigned(5 downto 0);
signal n18 : unsigned(0 downto 0);
signal n19 : unsigned(5 downto 0);
signal n20 : unsigned(5 downto 0);
signal n21 : unsigned(5 downto 0);
signal n22 : unsigned(0 downto 0);
signal n23 : unsigned(10 downto 0);
signal n24 : unsigned(0 downto 0);
signal n25 : unsigned(10 downto 0);
signal n26 : unsigned(21 downto 0);
signal n27 : unsigned(5 downto 0);
signal s28_1 : unsigned(0 downto 0);
signal s28_2 : unsigned(0 downto 0);
signal s28_3 : unsigned(0 downto 0);
signal s28_4 : unsigned(0 downto 0);
signal s28_5 : unsigned(0 downto 0);
signal s29_1 : unsigned(0 downto 0);
signal s29_2 : unsigned(0 downto 0);
signal s29_3 : unsigned(0 downto 0);
signal s29_4 : unsigned(0 downto 0);
signal s29_5 : unsigned(0 downto 0);
component cf_fp_mul_p_5_10_25 is
port (
i1 : in  unsigned(15 downto 0);
o1 : out unsigned(0 downto 0);
o2 : out unsigned(0 downto 0);
o3 : out unsigned(0 downto 0);
o4 : out unsigned(0 downto 0);
o5 : out unsigned(0 downto 0));
end component cf_fp_mul_p_5_10_25;
begin
n1 <= i1(15 downto 15);
n2 <= i1(14 downto 14) &
  i1(13 downto 13) &
  i1(12 downto 12) &
  i1(11 downto 11) &
  i1(10 downto 10);
n3 <= i1(9 downto 9) &
  i1(8 downto 8) &
  i1(7 downto 7) &
  i1(6 downto 6) &
  i1(5 downto 5) &
  i1(4 downto 4) &
  i1(3 downto 3) &
  i1(2 downto 2) &
  i1(1 downto 1) &
  i1(0 downto 0);
n4 <= i2(15 downto 15);
n5 <= i2(14 downto 14) &
  i2(13 downto 13) &
  i2(12 downto 12) &
  i2(11 downto 11) &
  i2(10 downto 10);
n6 <= i2(9 downto 9) &
  i2(8 downto 8) &
  i2(7 downto 7) &
  i2(6 downto 6) &
  i2(5 downto 5) &
  i2(4 downto 4) &
  i2(3 downto 3) &
  i2(2 downto 2) &
  i2(1 downto 1) &
  i2(0 downto 0);
n7 <= s29_2 or s29_1;
n8 <= s28_2 or s28_1;
n9 <= n7 or n8;
n10 <= s29_3 and s28_4;
n11 <= s29_4 and s28_3;
n12 <= n10 or n11;
n13 <= s29_3 or s28_3;
n14 <= s29_4 or s28_4;
n15 <= n1 xor n4;
n16 <= "0";
n17 <= n16 & n2;
n18 <= "0";
n19 <= n18 & n5;
n20 <= n17 + n19;
n21 <= n20 - n27;
n22 <= not s29_5;
n23 <= n22 & n3;
n24 <= not s28_5;
n25 <= n24 & n6;
n26 <= n23 * n25;
n27 <= "001111";
s28 : cf_fp_mul_p_5_10_25 port map (i2, s28_1, s28_2, s28_3, s28_4, s28_5);
s29 : cf_fp_mul_p_5_10_25 port map (i1, s29_1, s29_2, s29_3, s29_4, s29_5);
o7 <= n26;
o6 <= n21;
o5 <= n15;
o4 <= n14;
o3 <= n13;
o2 <= n12;
o1 <= n9;
end architecture rtl;

library ieee;
use ieee.std_logic_1164.all;
use ieee.numeric_std.all;
entity cf_fp_mul_p_5_10_23 is
port (
i1 : in  unsigned(5 downto 0);
o1 : out unsigned(0 downto 0));
end entity cf_fp_mul_p_5_10_23;
architecture rtl of cf_fp_mul_p_5_10_23 is
signal n1 : unsigned(0 downto 0);
signal n2 : unsigned(4 downto 0);
signal n3 : unsigned(0 downto 0);
signal n4 : unsigned(0 downto 0);
signal n5 : unsigned(0 downto 0);
signal n6 : unsigned(0 downto 0);
signal n7 : unsigned(0 downto 0);
signal n8 : unsigned(0 downto 0);
signal s9_1 : unsigned(0 downto 0);
signal s9_2 : unsigned(0 downto 0);
signal s9_3 : unsigned(0 downto 0);
signal s9_4 : unsigned(0 downto 0);
signal s9_5 : unsigned(0 downto 0);
component cf_fp_mul_p_5_10_28 is
port (
i1 : in  unsigned(4 downto 0);
o1 : out unsigned(0 downto 0);
o2 : out unsigned(0 downto 0);
o3 : out unsigned(0 downto 0);
o4 : out unsigned(0 downto 0);
o5 : out unsigned(0 downto 0));
end component cf_fp_mul_p_5_10_28;
begin
n1 <= i1(5 downto 5);
n2 <= i1(4 downto 4) &
  i1(3 downto 3) &
  i1(2 downto 2) &
  i1(1 downto 1) &
  i1(0 downto 0);
n3 <= n1 or s9_1;
n4 <= s9_2 or s9_3;
n5 <= s9_4 or s9_5;
n6 <= n3 or n4;
n7 <= n6 or n5;
n8 <= not n7;
s9 : cf_fp_mul_p_5_10_28 port map (n2, s9_1, s9_2, s9_3, s9_4, s9_5);
o1 <= n8;
end architecture rtl;

library ieee;
use ieee.std_logic_1164.all;
use ieee.numeric_std.all;
entity cf_fp_mul_p_5_10_22 is
port (
i1 : in  unsigned(5 downto 0);
i2 : in  unsigned(20 downto 0);
o1 : out unsigned(5 downto 0);
o2 : out unsigned(19 downto 0));
end entity cf_fp_mul_p_5_10_22;
architecture rtl of cf_fp_mul_p_5_10_22 is
signal n1 : unsigned(0 downto 0);
signal n2 : unsigned(0 downto 0);
signal n3 : unsigned(0 downto 0);
signal n4 : unsigned(5 downto 0);
signal n5 : unsigned(5 downto 0);
signal n6 : unsigned(5 downto 0);
signal n7 : unsigned(19 downto 0);
signal n8 : unsigned(19 downto 0);
signal n9 : unsigned(19 downto 0);
signal s10_1 : unsigned(0 downto 0);
component cf_fp_mul_p_5_10_23 is
port (
i1 : in  unsigned(5 downto 0);
o1 : out unsigned(0 downto 0));
end component cf_fp_mul_p_5_10_23;
begin
n1 <= i2(20 downto 20);
n2 <= n1 or s10_1;
n3 <= not n2;
n4 <= "000001";
n5 <= i1 - n4;
n6 <= n5 when n3 = "1" else i1;
n7 <= i2(19 downto 19) &
  i2(18 downto 18) &
  i2(17 downto 17) &
  i2(16 downto 16) &
  i2(15 downto 15) &
  i2(14 downto 14) &
  i2(13 downto 13) &
  i2(12 downto 12) &
  i2(11 downto 11) &
  i2(10 downto 10) &
  i2(9 downto 9) &
  i2(8 downto 8) &
  i2(7 downto 7) &
  i2(6 downto 6) &
  i2(5 downto 5) &
  i2(4 downto 4) &
  i2(3 downto 3) &
  i2(2 downto 2) &
  i2(1 downto 1) &
  i2(0 downto 0);
n8 <= i2(20 downto 20) &
  i2(19 downto 19) &
  i2(18 downto 18) &
  i2(17 downto 17) &
  i2(16 downto 16) &
  i2(15 downto 15) &
  i2(14 downto 14) &
  i2(13 downto 13) &
  i2(12 downto 12) &
  i2(11 downto 11) &
  i2(10 downto 10) &
  i2(9 downto 9) &
  i2(8 downto 8) &
  i2(7 downto 7) &
  i2(6 downto 6) &
  i2(5 downto 5) &
  i2(4 downto 4) &
  i2(3 downto 3) &
  i2(2 downto 2) &
  i2(1 downto 1);
n9 <= n7 when n3 = "1" else n8;
s10 : cf_fp_mul_p_5_10_23 port map (i1, s10_1);
o2 <= n9;
o1 <= n6;
end architecture rtl;

library ieee;
use ieee.std_logic_1164.all;
use ieee.numeric_std.all;
entity cf_fp_mul_p_5_10_21 is
port (
i1 : in  unsigned(5 downto 0);
i2 : in  unsigned(19 downto 0);
o1 : out unsigned(5 downto 0);
o2 : out unsigned(18 downto 0));
end entity cf_fp_mul_p_5_10_21;
architecture rtl of cf_fp_mul_p_5_10_21 is
signal n1 : unsigned(0 downto 0);
signal n2 : unsigned(0 downto 0);
signal n3 : unsigned(0 downto 0);
signal n4 : unsigned(5 downto 0);
signal n5 : unsigned(5 downto 0);
signal n6 : unsigned(5 downto 0);
signal n7 : unsigned(18 downto 0);
signal n8 : unsigned(18 downto 0);
signal n9 : unsigned(18 downto 0);
signal s10_1 : unsigned(0 downto 0);
component cf_fp_mul_p_5_10_23 is
port (
i1 : in  unsigned(5 downto 0);
o1 : out unsigned(0 downto 0));
end component cf_fp_mul_p_5_10_23;
begin
n1 <= i2(19 downto 19);
n2 <= n1 or s10_1;
n3 <= not n2;
n4 <= "000001";
n5 <= i1 - n4;
n6 <= n5 when n3 = "1" else i1;
n7 <= i2(18 downto 18) &
  i2(17 downto 17) &
  i2(16 downto 16) &
  i2(15 downto 15) &
  i2(14 downto 14) &
  i2(13 downto 13) &
  i2(12 downto 12) &
  i2(11 downto 11) &
  i2(10 downto 10) &
  i2(9 downto 9) &
  i2(8 downto 8) &
  i2(7 downto 7) &
  i2(6 downto 6) &
  i2(5 downto 5) &
  i2(4 downto 4) &
  i2(3 downto 3) &
  i2(2 downto 2) &
  i2(1 downto 1) &
  i2(0 downto 0);
n8 <= i2(19 downto 19) &
  i2(18 downto 18) &
  i2(17 downto 17) &
  i2(16 downto 16) &
  i2(15 downto 15) &
  i2(14 downto 14) &
  i2(13 downto 13) &
  i2(12 downto 12) &
  i2(11 downto 11) &
  i2(10 downto 10) &
  i2(9 downto 9) &
  i2(8 downto 8) &
  i2(7 downto 7) &
  i2(6 downto 6) &
  i2(5 downto 5) &
  i2(4 downto 4) &
  i2(3 downto 3) &
  i2(2 downto 2) &
  i2(1 downto 1);
n9 <= n7 when n3 = "1" else n8;
s10 : cf_fp_mul_p_5_10_23 port map (i1, s10_1);
o2 <= n9;
o1 <= n6;
end architecture rtl;

library ieee;
use ieee.std_logic_1164.all;
use ieee.numeric_std.all;
entity cf_fp_mul_p_5_10_20 is
port (
i1 : in  unsigned(5 downto 0);
i2 : in  unsigned(18 downto 0);
o1 : out unsigned(5 downto 0);
o2 : out unsigned(17 downto 0));
end entity cf_fp_mul_p_5_10_20;
architecture rtl of cf_fp_mul_p_5_10_20 is
signal n1 : unsigned(0 downto 0);
signal n2 : unsigned(0 downto 0);
signal n3 : unsigned(0 downto 0);
signal n4 : unsigned(5 downto 0);
signal n5 : unsigned(5 downto 0);
signal n6 : unsigned(5 downto 0);
signal n7 : unsigned(17 downto 0);
signal n8 : unsigned(17 downto 0);
signal n9 : unsigned(17 downto 0);
signal s10_1 : unsigned(0 downto 0);
component cf_fp_mul_p_5_10_23 is
port (
i1 : in  unsigned(5 downto 0);
o1 : out unsigned(0 downto 0));
end component cf_fp_mul_p_5_10_23;
begin
n1 <= i2(18 downto 18);
n2 <= n1 or s10_1;
n3 <= not n2;
n4 <= "000001";
n5 <= i1 - n4;
n6 <= n5 when n3 = "1" else i1;
n7 <= i2(17 downto 17) &
  i2(16 downto 16) &
  i2(15 downto 15) &
  i2(14 downto 14) &
  i2(13 downto 13) &
  i2(12 downto 12) &
  i2(11 downto 11) &
  i2(10 downto 10) &
  i2(9 downto 9) &
  i2(8 downto 8) &
  i2(7 downto 7) &
  i2(6 downto 6) &
  i2(5 downto 5) &
  i2(4 downto 4) &
  i2(3 downto 3) &
  i2(2 downto 2) &
  i2(1 downto 1) &
  i2(0 downto 0);
n8 <= i2(18 downto 18) &
  i2(17 downto 17) &
  i2(16 downto 16) &
  i2(15 downto 15) &
  i2(14 downto 14) &
  i2(13 downto 13) &
  i2(12 downto 12) &
  i2(11 downto 11) &
  i2(10 downto 10) &
  i2(9 downto 9) &
  i2(8 downto 8) &
  i2(7 downto 7) &
  i2(6 downto 6) &
  i2(5 downto 5) &
  i2(4 downto 4) &
  i2(3 downto 3) &
  i2(2 downto 2) &
  i2(1 downto 1);
n9 <= n7 when n3 = "1" else n8;
s10 : cf_fp_mul_p_5_10_23 port map (i1, s10_1);
o2 <= n9;
o1 <= n6;
end architecture rtl;

library ieee;
use ieee.std_logic_1164.all;
use ieee.numeric_std.all;
entity cf_fp_mul_p_5_10_19 is
port (
i1 : in  unsigned(5 downto 0);
i2 : in  unsigned(17 downto 0);
o1 : out unsigned(5 downto 0);
o2 : out unsigned(16 downto 0));
end entity cf_fp_mul_p_5_10_19;
architecture rtl of cf_fp_mul_p_5_10_19 is
signal n1 : unsigned(0 downto 0);
signal n2 : unsigned(0 downto 0);
signal n3 : unsigned(0 downto 0);
signal n4 : unsigned(5 downto 0);
signal n5 : unsigned(5 downto 0);
signal n6 : unsigned(5 downto 0);
signal n7 : unsigned(16 downto 0);
signal n8 : unsigned(16 downto 0);
signal n9 : unsigned(16 downto 0);
signal s10_1 : unsigned(0 downto 0);
component cf_fp_mul_p_5_10_23 is
port (
i1 : in  unsigned(5 downto 0);
o1 : out unsigned(0 downto 0));
end component cf_fp_mul_p_5_10_23;
begin
n1 <= i2(17 downto 17);
n2 <= n1 or s10_1;
n3 <= not n2;
n4 <= "000001";
n5 <= i1 - n4;
n6 <= n5 when n3 = "1" else i1;
n7 <= i2(16 downto 16) &
  i2(15 downto 15) &
  i2(14 downto 14) &
  i2(13 downto 13) &
  i2(12 downto 12) &
  i2(11 downto 11) &
  i2(10 downto 10) &
  i2(9 downto 9) &
  i2(8 downto 8) &
  i2(7 downto 7) &
  i2(6 downto 6) &
  i2(5 downto 5) &
  i2(4 downto 4) &
  i2(3 downto 3) &
  i2(2 downto 2) &
  i2(1 downto 1) &
  i2(0 downto 0);
n8 <= i2(17 downto 17) &
  i2(16 downto 16) &
  i2(15 downto 15) &
  i2(14 downto 14) &
  i2(13 downto 13) &
  i2(12 downto 12) &
  i2(11 downto 11) &
  i2(10 downto 10) &
  i2(9 downto 9) &
  i2(8 downto 8) &
  i2(7 downto 7) &
  i2(6 downto 6) &
  i2(5 downto 5) &
  i2(4 downto 4) &
  i2(3 downto 3) &
  i2(2 downto 2) &
  i2(1 downto 1);
n9 <= n7 when n3 = "1" else n8;
s10 : cf_fp_mul_p_5_10_23 port map (i1, s10_1);
o2 <= n9;
o1 <= n6;
end architecture rtl;

library ieee;
use ieee.std_logic_1164.all;
use ieee.numeric_std.all;
entity cf_fp_mul_p_5_10_18 is
port (
i1 : in  unsigned(5 downto 0);
i2 : in  unsigned(16 downto 0);
o1 : out unsigned(5 downto 0);
o2 : out unsigned(15 downto 0));
end entity cf_fp_mul_p_5_10_18;
architecture rtl of cf_fp_mul_p_5_10_18 is
signal n1 : unsigned(0 downto 0);
signal n2 : unsigned(0 downto 0);
signal n3 : unsigned(0 downto 0);
signal n4 : unsigned(5 downto 0);
signal n5 : unsigned(5 downto 0);
signal n6 : unsigned(5 downto 0);
signal n7 : unsigned(15 downto 0);
signal n8 : unsigned(15 downto 0);
signal n9 : unsigned(15 downto 0);
signal s10_1 : unsigned(0 downto 0);
component cf_fp_mul_p_5_10_23 is
port (
i1 : in  unsigned(5 downto 0);
o1 : out unsigned(0 downto 0));
end component cf_fp_mul_p_5_10_23;
begin
n1 <= i2(16 downto 16);
n2 <= n1 or s10_1;
n3 <= not n2;
n4 <= "000001";
n5 <= i1 - n4;
n6 <= n5 when n3 = "1" else i1;
n7 <= i2(15 downto 15) &
  i2(14 downto 14) &
  i2(13 downto 13) &
  i2(12 downto 12) &
  i2(11 downto 11) &
  i2(10 downto 10) &
  i2(9 downto 9) &
  i2(8 downto 8) &
  i2(7 downto 7) &
  i2(6 downto 6) &
  i2(5 downto 5) &
  i2(4 downto 4) &
  i2(3 downto 3) &
  i2(2 downto 2) &
  i2(1 downto 1) &
  i2(0 downto 0);
n8 <= i2(16 downto 16) &
  i2(15 downto 15) &
  i2(14 downto 14) &
  i2(13 downto 13) &
  i2(12 downto 12) &
  i2(11 downto 11) &
  i2(10 downto 10) &
  i2(9 downto 9) &
  i2(8 downto 8) &
  i2(7 downto 7) &
  i2(6 downto 6) &
  i2(5 downto 5) &
  i2(4 downto 4) &
  i2(3 downto 3) &
  i2(2 downto 2) &
  i2(1 downto 1);
n9 <= n7 when n3 = "1" else n8;
s10 : cf_fp_mul_p_5_10_23 port map (i1, s10_1);
o2 <= n9;
o1 <= n6;
end architecture rtl;

library ieee;
use ieee.std_logic_1164.all;
use ieee.numeric_std.all;
entity cf_fp_mul_p_5_10_17 is
port (
i1 : in  unsigned(5 downto 0);
i2 : in  unsigned(15 downto 0);
o1 : out unsigned(5 downto 0);
o2 : out unsigned(14 downto 0));
end entity cf_fp_mul_p_5_10_17;
architecture rtl of cf_fp_mul_p_5_10_17 is
signal n1 : unsigned(0 downto 0);
signal n2 : unsigned(0 downto 0);
signal n3 : unsigned(0 downto 0);
signal n4 : unsigned(5 downto 0);
signal n5 : unsigned(5 downto 0);
signal n6 : unsigned(5 downto 0);
signal n7 : unsigned(14 downto 0);
signal n8 : unsigned(14 downto 0);
signal n9 : unsigned(14 downto 0);
signal s10_1 : unsigned(0 downto 0);
component cf_fp_mul_p_5_10_23 is
port (
i1 : in  unsigned(5 downto 0);
o1 : out unsigned(0 downto 0));
end component cf_fp_mul_p_5_10_23;
begin
n1 <= i2(15 downto 15);
n2 <= n1 or s10_1;
n3 <= not n2;
n4 <= "000001";
n5 <= i1 - n4;
n6 <= n5 when n3 = "1" else i1;
n7 <= i2(14 downto 14) &
  i2(13 downto 13) &
  i2(12 downto 12) &
  i2(11 downto 11) &
  i2(10 downto 10) &
  i2(9 downto 9) &
  i2(8 downto 8) &
  i2(7 downto 7) &
  i2(6 downto 6) &
  i2(5 downto 5) &
  i2(4 downto 4) &
  i2(3 downto 3) &
  i2(2 downto 2) &
  i2(1 downto 1) &
  i2(0 downto 0);
n8 <= i2(15 downto 15) &
  i2(14 downto 14) &
  i2(13 downto 13) &
  i2(12 downto 12) &
  i2(11 downto 11) &
  i2(10 downto 10) &
  i2(9 downto 9) &
  i2(8 downto 8) &
  i2(7 downto 7) &
  i2(6 downto 6) &
  i2(5 downto 5) &
  i2(4 downto 4) &
  i2(3 downto 3) &
  i2(2 downto 2) &
  i2(1 downto 1);
n9 <= n7 when n3 = "1" else n8;
s10 : cf_fp_mul_p_5_10_23 port map (i1, s10_1);
o2 <= n9;
o1 <= n6;
end architecture rtl;

library ieee;
use ieee.std_logic_1164.all;
use ieee.numeric_std.all;
entity cf_fp_mul_p_5_10_16 is
port (
i1 : in  unsigned(5 downto 0);
i2 : in  unsigned(14 downto 0);
o1 : out unsigned(5 downto 0);
o2 : out unsigned(13 downto 0));
end entity cf_fp_mul_p_5_10_16;
architecture rtl of cf_fp_mul_p_5_10_16 is
signal n1 : unsigned(0 downto 0);
signal n2 : unsigned(0 downto 0);
signal n3 : unsigned(0 downto 0);
signal n4 : unsigned(5 downto 0);
signal n5 : unsigned(5 downto 0);
signal n6 : unsigned(5 downto 0);
signal n7 : unsigned(13 downto 0);
signal n8 : unsigned(13 downto 0);
signal n9 : unsigned(13 downto 0);
signal s10_1 : unsigned(0 downto 0);
component cf_fp_mul_p_5_10_23 is
port (
i1 : in  unsigned(5 downto 0);
o1 : out unsigned(0 downto 0));
end component cf_fp_mul_p_5_10_23;
begin
n1 <= i2(14 downto 14);
n2 <= n1 or s10_1;
n3 <= not n2;
n4 <= "000001";
n5 <= i1 - n4;
n6 <= n5 when n3 = "1" else i1;
n7 <= i2(13 downto 13) &
  i2(12 downto 12) &
  i2(11 downto 11) &
  i2(10 downto 10) &
  i2(9 downto 9) &
  i2(8 downto 8) &
  i2(7 downto 7) &
  i2(6 downto 6) &
  i2(5 downto 5) &
  i2(4 downto 4) &
  i2(3 downto 3) &
  i2(2 downto 2) &
  i2(1 downto 1) &
  i2(0 downto 0);
n8 <= i2(14 downto 14) &
  i2(13 downto 13) &
  i2(12 downto 12) &
  i2(11 downto 11) &
  i2(10 downto 10) &
  i2(9 downto 9) &
  i2(8 downto 8) &
  i2(7 downto 7) &
  i2(6 downto 6) &
  i2(5 downto 5) &
  i2(4 downto 4) &
  i2(3 downto 3) &
  i2(2 downto 2) &
  i2(1 downto 1);
n9 <= n7 when n3 = "1" else n8;
s10 : cf_fp_mul_p_5_10_23 port map (i1, s10_1);
o2 <= n9;
o1 <= n6;
end architecture rtl;

library ieee;
use ieee.std_logic_1164.all;
use ieee.numeric_std.all;
entity cf_fp_mul_p_5_10_15 is
port (
i1 : in  unsigned(5 downto 0);
i2 : in  unsigned(13 downto 0);
o1 : out unsigned(5 downto 0);
o2 : out unsigned(12 downto 0));
end entity cf_fp_mul_p_5_10_15;
architecture rtl of cf_fp_mul_p_5_10_15 is
signal n1 : unsigned(0 downto 0);
signal n2 : unsigned(0 downto 0);
signal n3 : unsigned(0 downto 0);
signal n4 : unsigned(5 downto 0);
signal n5 : unsigned(5 downto 0);
signal n6 : unsigned(5 downto 0);
signal n7 : unsigned(12 downto 0);
signal n8 : unsigned(12 downto 0);
signal n9 : unsigned(12 downto 0);
signal s10_1 : unsigned(0 downto 0);
component cf_fp_mul_p_5_10_23 is
port (
i1 : in  unsigned(5 downto 0);
o1 : out unsigned(0 downto 0));
end component cf_fp_mul_p_5_10_23;
begin
n1 <= i2(13 downto 13);
n2 <= n1 or s10_1;
n3 <= not n2;
n4 <= "000001";
n5 <= i1 - n4;
n6 <= n5 when n3 = "1" else i1;
n7 <= i2(12 downto 12) &
  i2(11 downto 11) &
  i2(10 downto 10) &
  i2(9 downto 9) &
  i2(8 downto 8) &
  i2(7 downto 7) &
  i2(6 downto 6) &
  i2(5 downto 5) &
  i2(4 downto 4) &
  i2(3 downto 3) &
  i2(2 downto 2) &
  i2(1 downto 1) &
  i2(0 downto 0);
n8 <= i2(13 downto 13) &
  i2(12 downto 12) &
  i2(11 downto 11) &
  i2(10 downto 10) &
  i2(9 downto 9) &
  i2(8 downto 8) &
  i2(7 downto 7) &
  i2(6 downto 6) &
  i2(5 downto 5) &
  i2(4 downto 4) &
  i2(3 downto 3) &
  i2(2 downto 2) &
  i2(1 downto 1);
n9 <= n7 when n3 = "1" else n8;
s10 : cf_fp_mul_p_5_10_23 port map (i1, s10_1);
o2 <= n9;
o1 <= n6;
end architecture rtl;

library ieee;
use ieee.std_logic_1164.all;
use ieee.numeric_std.all;
entity cf_fp_mul_p_5_10_14 is
port (
i1 : in  unsigned(5 downto 0);
i2 : in  unsigned(12 downto 0);
o1 : out unsigned(5 downto 0);
o2 : out unsigned(11 downto 0));
end entity cf_fp_mul_p_5_10_14;
architecture rtl of cf_fp_mul_p_5_10_14 is
signal n1 : unsigned(0 downto 0);
signal n2 : unsigned(0 downto 0);
signal n3 : unsigned(0 downto 0);
signal n4 : unsigned(5 downto 0);
signal n5 : unsigned(5 downto 0);
signal n6 : unsigned(5 downto 0);
signal n7 : unsigned(11 downto 0);
signal n8 : unsigned(11 downto 0);
signal n9 : unsigned(11 downto 0);
signal s10_1 : unsigned(0 downto 0);
component cf_fp_mul_p_5_10_23 is
port (
i1 : in  unsigned(5 downto 0);
o1 : out unsigned(0 downto 0));
end component cf_fp_mul_p_5_10_23;
begin
n1 <= i2(12 downto 12);
n2 <= n1 or s10_1;
n3 <= not n2;
n4 <= "000001";
n5 <= i1 - n4;
n6 <= n5 when n3 = "1" else i1;
n7 <= i2(11 downto 11) &
  i2(10 downto 10) &
  i2(9 downto 9) &
  i2(8 downto 8) &
  i2(7 downto 7) &
  i2(6 downto 6) &
  i2(5 downto 5) &
  i2(4 downto 4) &
  i2(3 downto 3) &
  i2(2 downto 2) &
  i2(1 downto 1) &
  i2(0 downto 0);
n8 <= i2(12 downto 12) &
  i2(11 downto 11) &
  i2(10 downto 10) &
  i2(9 downto 9) &
  i2(8 downto 8) &
  i2(7 downto 7) &
  i2(6 downto 6) &
  i2(5 downto 5) &
  i2(4 downto 4) &
  i2(3 downto 3) &
  i2(2 downto 2) &
  i2(1 downto 1);
n9 <= n7 when n3 = "1" else n8;
s10 : cf_fp_mul_p_5_10_23 port map (i1, s10_1);
o2 <= n9;
o1 <= n6;
end architecture rtl;

library ieee;
use ieee.std_logic_1164.all;
use ieee.numeric_std.all;
entity cf_fp_mul_p_5_10_13 is
port (
i1 : in  unsigned(5 downto 0);
i2 : in  unsigned(11 downto 0);
o1 : out unsigned(5 downto 0);
o2 : out unsigned(10 downto 0));
end entity cf_fp_mul_p_5_10_13;
architecture rtl of cf_fp_mul_p_5_10_13 is
signal n1 : unsigned(0 downto 0);
signal n2 : unsigned(0 downto 0);
signal n3 : unsigned(0 downto 0);
signal n4 : unsigned(5 downto 0);
signal n5 : unsigned(5 downto 0);
signal n6 : unsigned(5 downto 0);
signal n7 : unsigned(10 downto 0);
signal n8 : unsigned(10 downto 0);
signal n9 : unsigned(10 downto 0);
signal s10_1 : unsigned(0 downto 0);
component cf_fp_mul_p_5_10_23 is
port (
i1 : in  unsigned(5 downto 0);
o1 : out unsigned(0 downto 0));
end component cf_fp_mul_p_5_10_23;
begin
n1 <= i2(11 downto 11);
n2 <= n1 or s10_1;
n3 <= not n2;
n4 <= "000001";
n5 <= i1 - n4;
n6 <= n5 when n3 = "1" else i1;
n7 <= i2(10 downto 10) &
  i2(9 downto 9) &
  i2(8 downto 8) &
  i2(7 downto 7) &
  i2(6 downto 6) &
  i2(5 downto 5) &
  i2(4 downto 4) &
  i2(3 downto 3) &
  i2(2 downto 2) &
  i2(1 downto 1) &
  i2(0 downto 0);
n8 <= i2(11 downto 11) &
  i2(10 downto 10) &
  i2(9 downto 9) &
  i2(8 downto 8) &
  i2(7 downto 7) &
  i2(6 downto 6) &
  i2(5 downto 5) &
  i2(4 downto 4) &
  i2(3 downto 3) &
  i2(2 downto 2) &
  i2(1 downto 1);
n9 <= n7 when n3 = "1" else n8;
s10 : cf_fp_mul_p_5_10_23 port map (i1, s10_1);
o2 <= n9;
o1 <= n6;
end architecture rtl;

library ieee;
use ieee.std_logic_1164.all;
use ieee.numeric_std.all;
entity cf_fp_mul_p_5_10_12 is
port (
clock_c : in std_logic;
i1 : in  unsigned(0 downto 0);
i2 : in  unsigned(0 downto 0);
i3 : in  unsigned(0 downto 0);
i4 : in  unsigned(0 downto 0);
i5 : in  unsigned(0 downto 0);
i6 : in  unsigned(0 downto 0);
i7 : in  unsigned(0 downto 0);
i8 : in  unsigned(5 downto 0);
i9 : in  unsigned(11 downto 0);
o1 : out unsigned(0 downto 0);
o2 : out unsigned(0 downto 0);
o3 : out unsigned(0 downto 0);
o4 : out unsigned(0 downto 0);
o5 : out unsigned(0 downto 0);
o6 : out unsigned(5 downto 0);
o7 : out unsigned(10 downto 0));
end entity cf_fp_mul_p_5_10_12;
architecture rtl of cf_fp_mul_p_5_10_12 is
signal n1 : unsigned(0 downto 0) := "0";
signal n2 : unsigned(0 downto 0) := "0";
signal n3 : unsigned(0 downto 0) := "0";
signal n4 : unsigned(0 downto 0) := "0";
signal n5 : unsigned(0 downto 0) := "0";
signal n6 : unsigned(5 downto 0) := "000000";
signal n7 : unsigned(10 downto 0) := "00000000000";
signal s8_1 : unsigned(5 downto 0);
signal s8_2 : unsigned(10 downto 0);
component cf_fp_mul_p_5_10_13 is
port (
i1 : in  unsigned(5 downto 0);
i2 : in  unsigned(11 downto 0);
o1 : out unsigned(5 downto 0);
o2 : out unsigned(10 downto 0));
end component cf_fp_mul_p_5_10_13;
begin
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n1 <= "0";
    elsif i1 = "1" then
      n1 <= i3;
    end if;
  end if;
end process;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n2 <= "0";
    elsif i1 = "1" then
      n2 <= i4;
    end if;
  end if;
end process;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n3 <= "0";
    elsif i1 = "1" then
      n3 <= i5;
    end if;
  end if;
end process;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n4 <= "0";
    elsif i1 = "1" then
      n4 <= i6;
    end if;
  end if;
end process;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n5 <= "0";
    elsif i1 = "1" then
      n5 <= i7;
    end if;
  end if;
end process;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n6 <= "000000";
    elsif i1 = "1" then
      n6 <= s8_1;
    end if;
  end if;
end process;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n7 <= "00000000000";
    elsif i1 = "1" then
      n7 <= s8_2;
    end if;
  end if;
end process;
s8 : cf_fp_mul_p_5_10_13 port map (i8, i9, s8_1, s8_2);
o7 <= n7;
o6 <= n6;
o5 <= n5;
o4 <= n4;
o3 <= n3;
o2 <= n2;
o1 <= n1;
end architecture rtl;

library ieee;
use ieee.std_logic_1164.all;
use ieee.numeric_std.all;
entity cf_fp_mul_p_5_10_11 is
port (
clock_c : in std_logic;
i1 : in  unsigned(0 downto 0);
i2 : in  unsigned(0 downto 0);
i3 : in  unsigned(0 downto 0);
i4 : in  unsigned(0 downto 0);
i5 : in  unsigned(0 downto 0);
i6 : in  unsigned(0 downto 0);
i7 : in  unsigned(0 downto 0);
i8 : in  unsigned(5 downto 0);
i9 : in  unsigned(12 downto 0);
o1 : out unsigned(0 downto 0);
o2 : out unsigned(0 downto 0);
o3 : out unsigned(0 downto 0);
o4 : out unsigned(0 downto 0);
o5 : out unsigned(0 downto 0);
o6 : out unsigned(5 downto 0);
o7 : out unsigned(10 downto 0));
end entity cf_fp_mul_p_5_10_11;
architecture rtl of cf_fp_mul_p_5_10_11 is
signal n1 : unsigned(0 downto 0) := "0";
signal n2 : unsigned(0 downto 0) := "0";
signal n3 : unsigned(0 downto 0) := "0";
signal n4 : unsigned(0 downto 0) := "0";
signal n5 : unsigned(0 downto 0) := "0";
signal n6 : unsigned(5 downto 0) := "000000";
signal n7 : unsigned(11 downto 0) := "000000000000";
signal s8_1 : unsigned(5 downto 0);
signal s8_2 : unsigned(11 downto 0);
signal s9_1 : unsigned(0 downto 0);
signal s9_2 : unsigned(0 downto 0);
signal s9_3 : unsigned(0 downto 0);
signal s9_4 : unsigned(0 downto 0);
signal s9_5 : unsigned(0 downto 0);
signal s9_6 : unsigned(5 downto 0);
signal s9_7 : unsigned(10 downto 0);
component cf_fp_mul_p_5_10_14 is
port (
i1 : in  unsigned(5 downto 0);
i2 : in  unsigned(12 downto 0);
o1 : out unsigned(5 downto 0);
o2 : out unsigned(11 downto 0));
end component cf_fp_mul_p_5_10_14;
component cf_fp_mul_p_5_10_12 is
port (
clock_c : in std_logic;
i1 : in  unsigned(0 downto 0);
i2 : in  unsigned(0 downto 0);
i3 : in  unsigned(0 downto 0);
i4 : in  unsigned(0 downto 0);
i5 : in  unsigned(0 downto 0);
i6 : in  unsigned(0 downto 0);
i7 : in  unsigned(0 downto 0);
i8 : in  unsigned(5 downto 0);
i9 : in  unsigned(11 downto 0);
o1 : out unsigned(0 downto 0);
o2 : out unsigned(0 downto 0);
o3 : out unsigned(0 downto 0);
o4 : out unsigned(0 downto 0);
o5 : out unsigned(0 downto 0);
o6 : out unsigned(5 downto 0);
o7 : out unsigned(10 downto 0));
end component cf_fp_mul_p_5_10_12;
begin
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n1 <= "0";
    elsif i1 = "1" then
      n1 <= i3;
    end if;
  end if;
end process;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n2 <= "0";
    elsif i1 = "1" then
      n2 <= i4;
    end if;
  end if;
end process;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n3 <= "0";
    elsif i1 = "1" then
      n3 <= i5;
    end if;
  end if;
end process;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n4 <= "0";
    elsif i1 = "1" then
      n4 <= i6;
    end if;
  end if;
end process;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n5 <= "0";
    elsif i1 = "1" then
      n5 <= i7;
    end if;
  end if;
end process;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n6 <= "000000";
    elsif i1 = "1" then
      n6 <= s8_1;
    end if;
  end if;
end process;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n7 <= "000000000000";
    elsif i1 = "1" then
      n7 <= s8_2;
    end if;
  end if;
end process;
s8 : cf_fp_mul_p_5_10_14 port map (i8, i9, s8_1, s8_2);
s9 : cf_fp_mul_p_5_10_12 port map (clock_c, i1, i2, n1, n2, n3, n4, n5, n6, n7, s9_1, s9_2, s9_3, s9_4, s9_5, s9_6, s9_7);
o7 <= s9_7;
o6 <= s9_6;
o5 <= s9_5;
o4 <= s9_4;
o3 <= s9_3;
o2 <= s9_2;
o1 <= s9_1;
end architecture rtl;

library ieee;
use ieee.std_logic_1164.all;
use ieee.numeric_std.all;
entity cf_fp_mul_p_5_10_10 is
port (
clock_c : in std_logic;
i1 : in  unsigned(0 downto 0);
i2 : in  unsigned(0 downto 0);
i3 : in  unsigned(0 downto 0);
i4 : in  unsigned(0 downto 0);
i5 : in  unsigned(0 downto 0);
i6 : in  unsigned(0 downto 0);
i7 : in  unsigned(0 downto 0);
i8 : in  unsigned(5 downto 0);
i9 : in  unsigned(13 downto 0);
o1 : out unsigned(0 downto 0);
o2 : out unsigned(0 downto 0);
o3 : out unsigned(0 downto 0);
o4 : out unsigned(0 downto 0);
o5 : out unsigned(0 downto 0);
o6 : out unsigned(5 downto 0);
o7 : out unsigned(10 downto 0));
end entity cf_fp_mul_p_5_10_10;
architecture rtl of cf_fp_mul_p_5_10_10 is
signal n1 : unsigned(0 downto 0) := "0";
signal n2 : unsigned(0 downto 0) := "0";
signal n3 : unsigned(0 downto 0) := "0";
signal n4 : unsigned(0 downto 0) := "0";
signal n5 : unsigned(0 downto 0) := "0";
signal n6 : unsigned(5 downto 0) := "000000";
signal n7 : unsigned(12 downto 0) := "0000000000000";
signal s8_1 : unsigned(5 downto 0);
signal s8_2 : unsigned(12 downto 0);
signal s9_1 : unsigned(0 downto 0);
signal s9_2 : unsigned(0 downto 0);
signal s9_3 : unsigned(0 downto 0);
signal s9_4 : unsigned(0 downto 0);
signal s9_5 : unsigned(0 downto 0);
signal s9_6 : unsigned(5 downto 0);
signal s9_7 : unsigned(10 downto 0);
component cf_fp_mul_p_5_10_15 is
port (
i1 : in  unsigned(5 downto 0);
i2 : in  unsigned(13 downto 0);
o1 : out unsigned(5 downto 0);
o2 : out unsigned(12 downto 0));
end component cf_fp_mul_p_5_10_15;
component cf_fp_mul_p_5_10_11 is
port (
clock_c : in std_logic;
i1 : in  unsigned(0 downto 0);
i2 : in  unsigned(0 downto 0);
i3 : in  unsigned(0 downto 0);
i4 : in  unsigned(0 downto 0);
i5 : in  unsigned(0 downto 0);
i6 : in  unsigned(0 downto 0);
i7 : in  unsigned(0 downto 0);
i8 : in  unsigned(5 downto 0);
i9 : in  unsigned(12 downto 0);
o1 : out unsigned(0 downto 0);
o2 : out unsigned(0 downto 0);
o3 : out unsigned(0 downto 0);
o4 : out unsigned(0 downto 0);
o5 : out unsigned(0 downto 0);
o6 : out unsigned(5 downto 0);
o7 : out unsigned(10 downto 0));
end component cf_fp_mul_p_5_10_11;
begin
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n1 <= "0";
    elsif i1 = "1" then
      n1 <= i3;
    end if;
  end if;
end process;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n2 <= "0";
    elsif i1 = "1" then
      n2 <= i4;
    end if;
  end if;
end process;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n3 <= "0";
    elsif i1 = "1" then
      n3 <= i5;
    end if;
  end if;
end process;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n4 <= "0";
    elsif i1 = "1" then
      n4 <= i6;
    end if;
  end if;
end process;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n5 <= "0";
    elsif i1 = "1" then
      n5 <= i7;
    end if;
  end if;
end process;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n6 <= "000000";
    elsif i1 = "1" then
      n6 <= s8_1;
    end if;
  end if;
end process;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n7 <= "0000000000000";
    elsif i1 = "1" then
      n7 <= s8_2;
    end if;
  end if;
end process;
s8 : cf_fp_mul_p_5_10_15 port map (i8, i9, s8_1, s8_2);
s9 : cf_fp_mul_p_5_10_11 port map (clock_c, i1, i2, n1, n2, n3, n4, n5, n6, n7, s9_1, s9_2, s9_3, s9_4, s9_5, s9_6, s9_7);
o7 <= s9_7;
o6 <= s9_6;
o5 <= s9_5;
o4 <= s9_4;
o3 <= s9_3;
o2 <= s9_2;
o1 <= s9_1;
end architecture rtl;

library ieee;
use ieee.std_logic_1164.all;
use ieee.numeric_std.all;
entity cf_fp_mul_p_5_10_9 is
port (
clock_c : in std_logic;
i1 : in  unsigned(0 downto 0);
i2 : in  unsigned(0 downto 0);
i3 : in  unsigned(0 downto 0);
i4 : in  unsigned(0 downto 0);
i5 : in  unsigned(0 downto 0);
i6 : in  unsigned(0 downto 0);
i7 : in  unsigned(0 downto 0);
i8 : in  unsigned(5 downto 0);
i9 : in  unsigned(14 downto 0);
o1 : out unsigned(0 downto 0);
o2 : out unsigned(0 downto 0);
o3 : out unsigned(0 downto 0);
o4 : out unsigned(0 downto 0);
o5 : out unsigned(0 downto 0);
o6 : out unsigned(5 downto 0);
o7 : out unsigned(10 downto 0));
end entity cf_fp_mul_p_5_10_9;
architecture rtl of cf_fp_mul_p_5_10_9 is
signal n1 : unsigned(0 downto 0) := "0";
signal n2 : unsigned(0 downto 0) := "0";
signal n3 : unsigned(0 downto 0) := "0";
signal n4 : unsigned(0 downto 0) := "0";
signal n5 : unsigned(0 downto 0) := "0";
signal n6 : unsigned(5 downto 0) := "000000";
signal n7 : unsigned(13 downto 0) := "00000000000000";
signal s8_1 : unsigned(5 downto 0);
signal s8_2 : unsigned(13 downto 0);
signal s9_1 : unsigned(0 downto 0);
signal s9_2 : unsigned(0 downto 0);
signal s9_3 : unsigned(0 downto 0);
signal s9_4 : unsigned(0 downto 0);
signal s9_5 : unsigned(0 downto 0);
signal s9_6 : unsigned(5 downto 0);
signal s9_7 : unsigned(10 downto 0);
component cf_fp_mul_p_5_10_16 is
port (
i1 : in  unsigned(5 downto 0);
i2 : in  unsigned(14 downto 0);
o1 : out unsigned(5 downto 0);
o2 : out unsigned(13 downto 0));
end component cf_fp_mul_p_5_10_16;
component cf_fp_mul_p_5_10_10 is
port (
clock_c : in std_logic;
i1 : in  unsigned(0 downto 0);
i2 : in  unsigned(0 downto 0);
i3 : in  unsigned(0 downto 0);
i4 : in  unsigned(0 downto 0);
i5 : in  unsigned(0 downto 0);
i6 : in  unsigned(0 downto 0);
i7 : in  unsigned(0 downto 0);
i8 : in  unsigned(5 downto 0);
i9 : in  unsigned(13 downto 0);
o1 : out unsigned(0 downto 0);
o2 : out unsigned(0 downto 0);
o3 : out unsigned(0 downto 0);
o4 : out unsigned(0 downto 0);
o5 : out unsigned(0 downto 0);
o6 : out unsigned(5 downto 0);
o7 : out unsigned(10 downto 0));
end component cf_fp_mul_p_5_10_10;
begin
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n1 <= "0";
    elsif i1 = "1" then
      n1 <= i3;
    end if;
  end if;
end process;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n2 <= "0";
    elsif i1 = "1" then
      n2 <= i4;
    end if;
  end if;
end process;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n3 <= "0";
    elsif i1 = "1" then
      n3 <= i5;
    end if;
  end if;
end process;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n4 <= "0";
    elsif i1 = "1" then
      n4 <= i6;
    end if;
  end if;
end process;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n5 <= "0";
    elsif i1 = "1" then
      n5 <= i7;
    end if;
  end if;
end process;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n6 <= "000000";
    elsif i1 = "1" then
      n6 <= s8_1;
    end if;
  end if;
end process;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n7 <= "00000000000000";
    elsif i1 = "1" then
      n7 <= s8_2;
    end if;
  end if;
end process;
s8 : cf_fp_mul_p_5_10_16 port map (i8, i9, s8_1, s8_2);
s9 : cf_fp_mul_p_5_10_10 port map (clock_c, i1, i2, n1, n2, n3, n4, n5, n6, n7, s9_1, s9_2, s9_3, s9_4, s9_5, s9_6, s9_7);
o7 <= s9_7;
o6 <= s9_6;
o5 <= s9_5;
o4 <= s9_4;
o3 <= s9_3;
o2 <= s9_2;
o1 <= s9_1;
end architecture rtl;

library ieee;
use ieee.std_logic_1164.all;
use ieee.numeric_std.all;
entity cf_fp_mul_p_5_10_8 is
port (
clock_c : in std_logic;
i1 : in  unsigned(0 downto 0);
i2 : in  unsigned(0 downto 0);
i3 : in  unsigned(0 downto 0);
i4 : in  unsigned(0 downto 0);
i5 : in  unsigned(0 downto 0);
i6 : in  unsigned(0 downto 0);
i7 : in  unsigned(0 downto 0);
i8 : in  unsigned(5 downto 0);
i9 : in  unsigned(15 downto 0);
o1 : out unsigned(0 downto 0);
o2 : out unsigned(0 downto 0);
o3 : out unsigned(0 downto 0);
o4 : out unsigned(0 downto 0);
o5 : out unsigned(0 downto 0);
o6 : out unsigned(5 downto 0);
o7 : out unsigned(10 downto 0));
end entity cf_fp_mul_p_5_10_8;
architecture rtl of cf_fp_mul_p_5_10_8 is
signal n1 : unsigned(0 downto 0) := "0";
signal n2 : unsigned(0 downto 0) := "0";
signal n3 : unsigned(0 downto 0) := "0";
signal n4 : unsigned(0 downto 0) := "0";
signal n5 : unsigned(0 downto 0) := "0";
signal n6 : unsigned(5 downto 0) := "000000";
signal n7 : unsigned(14 downto 0) := "000000000000000";
signal s8_1 : unsigned(5 downto 0);
signal s8_2 : unsigned(14 downto 0);
signal s9_1 : unsigned(0 downto 0);
signal s9_2 : unsigned(0 downto 0);
signal s9_3 : unsigned(0 downto 0);
signal s9_4 : unsigned(0 downto 0);
signal s9_5 : unsigned(0 downto 0);
signal s9_6 : unsigned(5 downto 0);
signal s9_7 : unsigned(10 downto 0);
component cf_fp_mul_p_5_10_17 is
port (
i1 : in  unsigned(5 downto 0);
i2 : in  unsigned(15 downto 0);
o1 : out unsigned(5 downto 0);
o2 : out unsigned(14 downto 0));
end component cf_fp_mul_p_5_10_17;
component cf_fp_mul_p_5_10_9 is
port (
clock_c : in std_logic;
i1 : in  unsigned(0 downto 0);
i2 : in  unsigned(0 downto 0);
i3 : in  unsigned(0 downto 0);
i4 : in  unsigned(0 downto 0);
i5 : in  unsigned(0 downto 0);
i6 : in  unsigned(0 downto 0);
i7 : in  unsigned(0 downto 0);
i8 : in  unsigned(5 downto 0);
i9 : in  unsigned(14 downto 0);
o1 : out unsigned(0 downto 0);
o2 : out unsigned(0 downto 0);
o3 : out unsigned(0 downto 0);
o4 : out unsigned(0 downto 0);
o5 : out unsigned(0 downto 0);
o6 : out unsigned(5 downto 0);
o7 : out unsigned(10 downto 0));
end component cf_fp_mul_p_5_10_9;
begin
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n1 <= "0";
    elsif i1 = "1" then
      n1 <= i3;
    end if;
  end if;
end process;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n2 <= "0";
    elsif i1 = "1" then
      n2 <= i4;
    end if;
  end if;
end process;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n3 <= "0";
    elsif i1 = "1" then
      n3 <= i5;
    end if;
  end if;
end process;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n4 <= "0";
    elsif i1 = "1" then
      n4 <= i6;
    end if;
  end if;
end process;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n5 <= "0";
    elsif i1 = "1" then
      n5 <= i7;
    end if;
  end if;
end process;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n6 <= "000000";
    elsif i1 = "1" then
      n6 <= s8_1;
    end if;
  end if;
end process;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n7 <= "000000000000000";
    elsif i1 = "1" then
      n7 <= s8_2;
    end if;
  end if;
end process;
s8 : cf_fp_mul_p_5_10_17 port map (i8, i9, s8_1, s8_2);
s9 : cf_fp_mul_p_5_10_9 port map (clock_c, i1, i2, n1, n2, n3, n4, n5, n6, n7, s9_1, s9_2, s9_3, s9_4, s9_5, s9_6, s9_7);
o7 <= s9_7;
o6 <= s9_6;
o5 <= s9_5;
o4 <= s9_4;
o3 <= s9_3;
o2 <= s9_2;
o1 <= s9_1;
end architecture rtl;

library ieee;
use ieee.std_logic_1164.all;
use ieee.numeric_std.all;
entity cf_fp_mul_p_5_10_7 is
port (
clock_c : in std_logic;
i1 : in  unsigned(0 downto 0);
i2 : in  unsigned(0 downto 0);
i3 : in  unsigned(0 downto 0);
i4 : in  unsigned(0 downto 0);
i5 : in  unsigned(0 downto 0);
i6 : in  unsigned(0 downto 0);
i7 : in  unsigned(0 downto 0);
i8 : in  unsigned(5 downto 0);
i9 : in  unsigned(16 downto 0);
o1 : out unsigned(0 downto 0);
o2 : out unsigned(0 downto 0);
o3 : out unsigned(0 downto 0);
o4 : out unsigned(0 downto 0);
o5 : out unsigned(0 downto 0);
o6 : out unsigned(5 downto 0);
o7 : out unsigned(10 downto 0));
end entity cf_fp_mul_p_5_10_7;
architecture rtl of cf_fp_mul_p_5_10_7 is
signal n1 : unsigned(0 downto 0) := "0";
signal n2 : unsigned(0 downto 0) := "0";
signal n3 : unsigned(0 downto 0) := "0";
signal n4 : unsigned(0 downto 0) := "0";
signal n5 : unsigned(0 downto 0) := "0";
signal n6 : unsigned(5 downto 0) := "000000";
signal n7 : unsigned(15 downto 0) := "0000000000000000";
signal s8_1 : unsigned(5 downto 0);
signal s8_2 : unsigned(15 downto 0);
signal s9_1 : unsigned(0 downto 0);
signal s9_2 : unsigned(0 downto 0);
signal s9_3 : unsigned(0 downto 0);
signal s9_4 : unsigned(0 downto 0);
signal s9_5 : unsigned(0 downto 0);
signal s9_6 : unsigned(5 downto 0);
signal s9_7 : unsigned(10 downto 0);
component cf_fp_mul_p_5_10_18 is
port (
i1 : in  unsigned(5 downto 0);
i2 : in  unsigned(16 downto 0);
o1 : out unsigned(5 downto 0);
o2 : out unsigned(15 downto 0));
end component cf_fp_mul_p_5_10_18;
component cf_fp_mul_p_5_10_8 is
port (
clock_c : in std_logic;
i1 : in  unsigned(0 downto 0);
i2 : in  unsigned(0 downto 0);
i3 : in  unsigned(0 downto 0);
i4 : in  unsigned(0 downto 0);
i5 : in  unsigned(0 downto 0);
i6 : in  unsigned(0 downto 0);
i7 : in  unsigned(0 downto 0);
i8 : in  unsigned(5 downto 0);
i9 : in  unsigned(15 downto 0);
o1 : out unsigned(0 downto 0);
o2 : out unsigned(0 downto 0);
o3 : out unsigned(0 downto 0);
o4 : out unsigned(0 downto 0);
o5 : out unsigned(0 downto 0);
o6 : out unsigned(5 downto 0);
o7 : out unsigned(10 downto 0));
end component cf_fp_mul_p_5_10_8;
begin
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n1 <= "0";
    elsif i1 = "1" then
      n1 <= i3;
    end if;
  end if;
end process;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n2 <= "0";
    elsif i1 = "1" then
      n2 <= i4;
    end if;
  end if;
end process;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n3 <= "0";
    elsif i1 = "1" then
      n3 <= i5;
    end if;
  end if;
end process;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n4 <= "0";
    elsif i1 = "1" then
      n4 <= i6;
    end if;
  end if;
end process;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n5 <= "0";
    elsif i1 = "1" then
      n5 <= i7;
    end if;
  end if;
end process;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n6 <= "000000";
    elsif i1 = "1" then
      n6 <= s8_1;
    end if;
  end if;
end process;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n7 <= "0000000000000000";
    elsif i1 = "1" then
      n7 <= s8_2;
    end if;
  end if;
end process;
s8 : cf_fp_mul_p_5_10_18 port map (i8, i9, s8_1, s8_2);
s9 : cf_fp_mul_p_5_10_8 port map (clock_c, i1, i2, n1, n2, n3, n4, n5, n6, n7, s9_1, s9_2, s9_3, s9_4, s9_5, s9_6, s9_7);
o7 <= s9_7;
o6 <= s9_6;
o5 <= s9_5;
o4 <= s9_4;
o3 <= s9_3;
o2 <= s9_2;
o1 <= s9_1;
end architecture rtl;

library ieee;
use ieee.std_logic_1164.all;
use ieee.numeric_std.all;
entity cf_fp_mul_p_5_10_6 is
port (
clock_c : in std_logic;
i1 : in  unsigned(0 downto 0);
i2 : in  unsigned(0 downto 0);
i3 : in  unsigned(0 downto 0);
i4 : in  unsigned(0 downto 0);
i5 : in  unsigned(0 downto 0);
i6 : in  unsigned(0 downto 0);
i7 : in  unsigned(0 downto 0);
i8 : in  unsigned(5 downto 0);
i9 : in  unsigned(17 downto 0);
o1 : out unsigned(0 downto 0);
o2 : out unsigned(0 downto 0);
o3 : out unsigned(0 downto 0);
o4 : out unsigned(0 downto 0);
o5 : out unsigned(0 downto 0);
o6 : out unsigned(5 downto 0);
o7 : out unsigned(10 downto 0));
end entity cf_fp_mul_p_5_10_6;
architecture rtl of cf_fp_mul_p_5_10_6 is
signal n1 : unsigned(0 downto 0) := "0";
signal n2 : unsigned(0 downto 0) := "0";
signal n3 : unsigned(0 downto 0) := "0";
signal n4 : unsigned(0 downto 0) := "0";
signal n5 : unsigned(0 downto 0) := "0";
signal n6 : unsigned(5 downto 0) := "000000";
signal n7 : unsigned(16 downto 0) := "00000000000000000";
signal s8_1 : unsigned(5 downto 0);
signal s8_2 : unsigned(16 downto 0);
signal s9_1 : unsigned(0 downto 0);
signal s9_2 : unsigned(0 downto 0);
signal s9_3 : unsigned(0 downto 0);
signal s9_4 : unsigned(0 downto 0);
signal s9_5 : unsigned(0 downto 0);
signal s9_6 : unsigned(5 downto 0);
signal s9_7 : unsigned(10 downto 0);
component cf_fp_mul_p_5_10_19 is
port (
i1 : in  unsigned(5 downto 0);
i2 : in  unsigned(17 downto 0);
o1 : out unsigned(5 downto 0);
o2 : out unsigned(16 downto 0));
end component cf_fp_mul_p_5_10_19;
component cf_fp_mul_p_5_10_7 is
port (
clock_c : in std_logic;
i1 : in  unsigned(0 downto 0);
i2 : in  unsigned(0 downto 0);
i3 : in  unsigned(0 downto 0);
i4 : in  unsigned(0 downto 0);
i5 : in  unsigned(0 downto 0);
i6 : in  unsigned(0 downto 0);
i7 : in  unsigned(0 downto 0);
i8 : in  unsigned(5 downto 0);
i9 : in  unsigned(16 downto 0);
o1 : out unsigned(0 downto 0);
o2 : out unsigned(0 downto 0);
o3 : out unsigned(0 downto 0);
o4 : out unsigned(0 downto 0);
o5 : out unsigned(0 downto 0);
o6 : out unsigned(5 downto 0);
o7 : out unsigned(10 downto 0));
end component cf_fp_mul_p_5_10_7;
begin
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n1 <= "0";
    elsif i1 = "1" then
      n1 <= i3;
    end if;
  end if;
end process;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n2 <= "0";
    elsif i1 = "1" then
      n2 <= i4;
    end if;
  end if;
end process;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n3 <= "0";
    elsif i1 = "1" then
      n3 <= i5;
    end if;
  end if;
end process;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n4 <= "0";
    elsif i1 = "1" then
      n4 <= i6;
    end if;
  end if;
end process;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n5 <= "0";
    elsif i1 = "1" then
      n5 <= i7;
    end if;
  end if;
end process;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n6 <= "000000";
    elsif i1 = "1" then
      n6 <= s8_1;
    end if;
  end if;
end process;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n7 <= "00000000000000000";
    elsif i1 = "1" then
      n7 <= s8_2;
    end if;
  end if;
end process;
s8 : cf_fp_mul_p_5_10_19 port map (i8, i9, s8_1, s8_2);
s9 : cf_fp_mul_p_5_10_7 port map (clock_c, i1, i2, n1, n2, n3, n4, n5, n6, n7, s9_1, s9_2, s9_3, s9_4, s9_5, s9_6, s9_7);
o7 <= s9_7;
o6 <= s9_6;
o5 <= s9_5;
o4 <= s9_4;
o3 <= s9_3;
o2 <= s9_2;
o1 <= s9_1;
end architecture rtl;

library ieee;
use ieee.std_logic_1164.all;
use ieee.numeric_std.all;
entity cf_fp_mul_p_5_10_5 is
port (
clock_c : in std_logic;
i1 : in  unsigned(0 downto 0);
i2 : in  unsigned(0 downto 0);
i3 : in  unsigned(0 downto 0);
i4 : in  unsigned(0 downto 0);
i5 : in  unsigned(0 downto 0);
i6 : in  unsigned(0 downto 0);
i7 : in  unsigned(0 downto 0);
i8 : in  unsigned(5 downto 0);
i9 : in  unsigned(18 downto 0);
o1 : out unsigned(0 downto 0);
o2 : out unsigned(0 downto 0);
o3 : out unsigned(0 downto 0);
o4 : out unsigned(0 downto 0);
o5 : out unsigned(0 downto 0);
o6 : out unsigned(5 downto 0);
o7 : out unsigned(10 downto 0));
end entity cf_fp_mul_p_5_10_5;
architecture rtl of cf_fp_mul_p_5_10_5 is
signal n1 : unsigned(0 downto 0) := "0";
signal n2 : unsigned(0 downto 0) := "0";
signal n3 : unsigned(0 downto 0) := "0";
signal n4 : unsigned(0 downto 0) := "0";
signal n5 : unsigned(0 downto 0) := "0";
signal n6 : unsigned(5 downto 0) := "000000";
signal n7 : unsigned(17 downto 0) := "000000000000000000";
signal s8_1 : unsigned(5 downto 0);
signal s8_2 : unsigned(17 downto 0);
signal s9_1 : unsigned(0 downto 0);
signal s9_2 : unsigned(0 downto 0);
signal s9_3 : unsigned(0 downto 0);
signal s9_4 : unsigned(0 downto 0);
signal s9_5 : unsigned(0 downto 0);
signal s9_6 : unsigned(5 downto 0);
signal s9_7 : unsigned(10 downto 0);
component cf_fp_mul_p_5_10_20 is
port (
i1 : in  unsigned(5 downto 0);
i2 : in  unsigned(18 downto 0);
o1 : out unsigned(5 downto 0);
o2 : out unsigned(17 downto 0));
end component cf_fp_mul_p_5_10_20;
component cf_fp_mul_p_5_10_6 is
port (
clock_c : in std_logic;
i1 : in  unsigned(0 downto 0);
i2 : in  unsigned(0 downto 0);
i3 : in  unsigned(0 downto 0);
i4 : in  unsigned(0 downto 0);
i5 : in  unsigned(0 downto 0);
i6 : in  unsigned(0 downto 0);
i7 : in  unsigned(0 downto 0);
i8 : in  unsigned(5 downto 0);
i9 : in  unsigned(17 downto 0);
o1 : out unsigned(0 downto 0);
o2 : out unsigned(0 downto 0);
o3 : out unsigned(0 downto 0);
o4 : out unsigned(0 downto 0);
o5 : out unsigned(0 downto 0);
o6 : out unsigned(5 downto 0);
o7 : out unsigned(10 downto 0));
end component cf_fp_mul_p_5_10_6;
begin
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n1 <= "0";
    elsif i1 = "1" then
      n1 <= i3;
    end if;
  end if;
end process;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n2 <= "0";
    elsif i1 = "1" then
      n2 <= i4;
    end if;
  end if;
end process;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n3 <= "0";
    elsif i1 = "1" then
      n3 <= i5;
    end if;
  end if;
end process;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n4 <= "0";
    elsif i1 = "1" then
      n4 <= i6;
    end if;
  end if;
end process;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n5 <= "0";
    elsif i1 = "1" then
      n5 <= i7;
    end if;
  end if;
end process;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n6 <= "000000";
    elsif i1 = "1" then
      n6 <= s8_1;
    end if;
  end if;
end process;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n7 <= "000000000000000000";
    elsif i1 = "1" then
      n7 <= s8_2;
    end if;
  end if;
end process;
s8 : cf_fp_mul_p_5_10_20 port map (i8, i9, s8_1, s8_2);
s9 : cf_fp_mul_p_5_10_6 port map (clock_c, i1, i2, n1, n2, n3, n4, n5, n6, n7, s9_1, s9_2, s9_3, s9_4, s9_5, s9_6, s9_7);
o7 <= s9_7;
o6 <= s9_6;
o5 <= s9_5;
o4 <= s9_4;
o3 <= s9_3;
o2 <= s9_2;
o1 <= s9_1;
end architecture rtl;

library ieee;
use ieee.std_logic_1164.all;
use ieee.numeric_std.all;
entity cf_fp_mul_p_5_10_4 is
port (
clock_c : in std_logic;
i1 : in  unsigned(0 downto 0);
i2 : in  unsigned(0 downto 0);
i3 : in  unsigned(0 downto 0);
i4 : in  unsigned(0 downto 0);
i5 : in  unsigned(0 downto 0);
i6 : in  unsigned(0 downto 0);
i7 : in  unsigned(0 downto 0);
i8 : in  unsigned(5 downto 0);
i9 : in  unsigned(19 downto 0);
o1 : out unsigned(0 downto 0);
o2 : out unsigned(0 downto 0);
o3 : out unsigned(0 downto 0);
o4 : out unsigned(0 downto 0);
o5 : out unsigned(0 downto 0);
o6 : out unsigned(5 downto 0);
o7 : out unsigned(10 downto 0));
end entity cf_fp_mul_p_5_10_4;
architecture rtl of cf_fp_mul_p_5_10_4 is
signal n1 : unsigned(0 downto 0) := "0";
signal n2 : unsigned(0 downto 0) := "0";
signal n3 : unsigned(0 downto 0) := "0";
signal n4 : unsigned(0 downto 0) := "0";
signal n5 : unsigned(0 downto 0) := "0";
signal n6 : unsigned(5 downto 0) := "000000";
signal n7 : unsigned(18 downto 0) := "0000000000000000000";
signal s8_1 : unsigned(5 downto 0);
signal s8_2 : unsigned(18 downto 0);
signal s9_1 : unsigned(0 downto 0);
signal s9_2 : unsigned(0 downto 0);
signal s9_3 : unsigned(0 downto 0);
signal s9_4 : unsigned(0 downto 0);
signal s9_5 : unsigned(0 downto 0);
signal s9_6 : unsigned(5 downto 0);
signal s9_7 : unsigned(10 downto 0);
component cf_fp_mul_p_5_10_21 is
port (
i1 : in  unsigned(5 downto 0);
i2 : in  unsigned(19 downto 0);
o1 : out unsigned(5 downto 0);
o2 : out unsigned(18 downto 0));
end component cf_fp_mul_p_5_10_21;
component cf_fp_mul_p_5_10_5 is
port (
clock_c : in std_logic;
i1 : in  unsigned(0 downto 0);
i2 : in  unsigned(0 downto 0);
i3 : in  unsigned(0 downto 0);
i4 : in  unsigned(0 downto 0);
i5 : in  unsigned(0 downto 0);
i6 : in  unsigned(0 downto 0);
i7 : in  unsigned(0 downto 0);
i8 : in  unsigned(5 downto 0);
i9 : in  unsigned(18 downto 0);
o1 : out unsigned(0 downto 0);
o2 : out unsigned(0 downto 0);
o3 : out unsigned(0 downto 0);
o4 : out unsigned(0 downto 0);
o5 : out unsigned(0 downto 0);
o6 : out unsigned(5 downto 0);
o7 : out unsigned(10 downto 0));
end component cf_fp_mul_p_5_10_5;
begin
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n1 <= "0";
    elsif i1 = "1" then
      n1 <= i3;
    end if;
  end if;
end process;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n2 <= "0";
    elsif i1 = "1" then
      n2 <= i4;
    end if;
  end if;
end process;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n3 <= "0";
    elsif i1 = "1" then
      n3 <= i5;
    end if;
  end if;
end process;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n4 <= "0";
    elsif i1 = "1" then
      n4 <= i6;
    end if;
  end if;
end process;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n5 <= "0";
    elsif i1 = "1" then
      n5 <= i7;
    end if;
  end if;
end process;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n6 <= "000000";
    elsif i1 = "1" then
      n6 <= s8_1;
    end if;
  end if;
end process;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n7 <= "0000000000000000000";
    elsif i1 = "1" then
      n7 <= s8_2;
    end if;
  end if;
end process;
s8 : cf_fp_mul_p_5_10_21 port map (i8, i9, s8_1, s8_2);
s9 : cf_fp_mul_p_5_10_5 port map (clock_c, i1, i2, n1, n2, n3, n4, n5, n6, n7, s9_1, s9_2, s9_3, s9_4, s9_5, s9_6, s9_7);
o7 <= s9_7;
o6 <= s9_6;
o5 <= s9_5;
o4 <= s9_4;
o3 <= s9_3;
o2 <= s9_2;
o1 <= s9_1;
end architecture rtl;

library ieee;
use ieee.std_logic_1164.all;
use ieee.numeric_std.all;
entity cf_fp_mul_p_5_10_3 is
port (
clock_c : in std_logic;
i1 : in  unsigned(0 downto 0);
i2 : in  unsigned(0 downto 0);
i3 : in  unsigned(0 downto 0);
i4 : in  unsigned(0 downto 0);
i5 : in  unsigned(0 downto 0);
i6 : in  unsigned(0 downto 0);
i7 : in  unsigned(0 downto 0);
i8 : in  unsigned(5 downto 0);
i9 : in  unsigned(20 downto 0);
o1 : out unsigned(0 downto 0);
o2 : out unsigned(0 downto 0);
o3 : out unsigned(0 downto 0);
o4 : out unsigned(0 downto 0);
o5 : out unsigned(0 downto 0);
o6 : out unsigned(5 downto 0);
o7 : out unsigned(10 downto 0));
end entity cf_fp_mul_p_5_10_3;
architecture rtl of cf_fp_mul_p_5_10_3 is
signal n1 : unsigned(0 downto 0) := "0";
signal n2 : unsigned(0 downto 0) := "0";
signal n3 : unsigned(0 downto 0) := "0";
signal n4 : unsigned(0 downto 0) := "0";
signal n5 : unsigned(0 downto 0) := "0";
signal n6 : unsigned(5 downto 0) := "000000";
signal n7 : unsigned(19 downto 0) := "00000000000000000000";
signal s8_1 : unsigned(5 downto 0);
signal s8_2 : unsigned(19 downto 0);
signal s9_1 : unsigned(0 downto 0);
signal s9_2 : unsigned(0 downto 0);
signal s9_3 : unsigned(0 downto 0);
signal s9_4 : unsigned(0 downto 0);
signal s9_5 : unsigned(0 downto 0);
signal s9_6 : unsigned(5 downto 0);
signal s9_7 : unsigned(10 downto 0);
component cf_fp_mul_p_5_10_22 is
port (
i1 : in  unsigned(5 downto 0);
i2 : in  unsigned(20 downto 0);
o1 : out unsigned(5 downto 0);
o2 : out unsigned(19 downto 0));
end component cf_fp_mul_p_5_10_22;
component cf_fp_mul_p_5_10_4 is
port (
clock_c : in std_logic;
i1 : in  unsigned(0 downto 0);
i2 : in  unsigned(0 downto 0);
i3 : in  unsigned(0 downto 0);
i4 : in  unsigned(0 downto 0);
i5 : in  unsigned(0 downto 0);
i6 : in  unsigned(0 downto 0);
i7 : in  unsigned(0 downto 0);
i8 : in  unsigned(5 downto 0);
i9 : in  unsigned(19 downto 0);
o1 : out unsigned(0 downto 0);
o2 : out unsigned(0 downto 0);
o3 : out unsigned(0 downto 0);
o4 : out unsigned(0 downto 0);
o5 : out unsigned(0 downto 0);
o6 : out unsigned(5 downto 0);
o7 : out unsigned(10 downto 0));
end component cf_fp_mul_p_5_10_4;
begin
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n1 <= "0";
    elsif i1 = "1" then
      n1 <= i3;
    end if;
  end if;
end process;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n2 <= "0";
    elsif i1 = "1" then
      n2 <= i4;
    end if;
  end if;
end process;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n3 <= "0";
    elsif i1 = "1" then
      n3 <= i5;
    end if;
  end if;
end process;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n4 <= "0";
    elsif i1 = "1" then
      n4 <= i6;
    end if;
  end if;
end process;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n5 <= "0";
    elsif i1 = "1" then
      n5 <= i7;
    end if;
  end if;
end process;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n6 <= "000000";
    elsif i1 = "1" then
      n6 <= s8_1;
    end if;
  end if;
end process;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n7 <= "00000000000000000000";
    elsif i1 = "1" then
      n7 <= s8_2;
    end if;
  end if;
end process;
s8 : cf_fp_mul_p_5_10_22 port map (i8, i9, s8_1, s8_2);
s9 : cf_fp_mul_p_5_10_4 port map (clock_c, i1, i2, n1, n2, n3, n4, n5, n6, n7, s9_1, s9_2, s9_3, s9_4, s9_5, s9_6, s9_7);
o7 <= s9_7;
o6 <= s9_6;
o5 <= s9_5;
o4 <= s9_4;
o3 <= s9_3;
o2 <= s9_2;
o1 <= s9_1;
end architecture rtl;

library ieee;
use ieee.std_logic_1164.all;
use ieee.numeric_std.all;
entity cf_fp_mul_p_5_10_2 is
port (
clock_c : in std_logic;
i1 : in  unsigned(0 downto 0);
i2 : in  unsigned(0 downto 0);
i3 : in  unsigned(15 downto 0);
i4 : in  unsigned(15 downto 0);
o1 : out unsigned(15 downto 0));
end entity cf_fp_mul_p_5_10_2;
architecture rtl of cf_fp_mul_p_5_10_2 is
signal n1 : unsigned(15 downto 0) := "0000000000000000";
signal n2 : unsigned(15 downto 0) := "0000000000000000";
signal n3 : unsigned(0 downto 0) := "0";
signal n4 : unsigned(0 downto 0) := "0";
signal n5 : unsigned(0 downto 0) := "0";
signal n6 : unsigned(0 downto 0) := "0";
signal n7 : unsigned(0 downto 0) := "0";
signal n8 : unsigned(5 downto 0) := "000000";
signal n9 : unsigned(21 downto 0) := "0000000000000000000000";
signal n10 : unsigned(0 downto 0);
signal n11 : unsigned(5 downto 0);
signal n12 : unsigned(5 downto 0);
signal n13 : unsigned(5 downto 0);
signal n14 : unsigned(20 downto 0);
signal n15 : unsigned(20 downto 0);
signal n16 : unsigned(20 downto 0);
signal n17 : unsigned(0 downto 0) := "0";
signal n18 : unsigned(0 downto 0) := "0";
signal n19 : unsigned(0 downto 0) := "0";
signal n20 : unsigned(0 downto 0) := "0";
signal n21 : unsigned(0 downto 0) := "0";
signal n22 : unsigned(5 downto 0) := "000000";
signal n23 : unsigned(20 downto 0) := "000000000000000000000";
signal n24 : unsigned(15 downto 0) := "0000000000000000";
signal s25_1 : unsigned(15 downto 0);
signal s26_1 : unsigned(0 downto 0);
signal s26_2 : unsigned(0 downto 0);
signal s26_3 : unsigned(0 downto 0);
signal s26_4 : unsigned(0 downto 0);
signal s26_5 : unsigned(0 downto 0);
signal s26_6 : unsigned(5 downto 0);
signal s26_7 : unsigned(21 downto 0);
signal s27_1 : unsigned(0 downto 0);
signal s27_2 : unsigned(0 downto 0);
signal s27_3 : unsigned(0 downto 0);
signal s27_4 : unsigned(0 downto 0);
signal s27_5 : unsigned(0 downto 0);
signal s27_6 : unsigned(5 downto 0);
signal s27_7 : unsigned(10 downto 0);
component cf_fp_mul_p_5_10_29 is
port (
i1 : in  unsigned(0 downto 0);
i2 : in  unsigned(0 downto 0);
i3 : in  unsigned(0 downto 0);
i4 : in  unsigned(0 downto 0);
i5 : in  unsigned(0 downto 0);
i6 : in  unsigned(5 downto 0);
i7 : in  unsigned(10 downto 0);
o1 : out unsigned(15 downto 0));
end component cf_fp_mul_p_5_10_29;
component cf_fp_mul_p_5_10_24 is
port (
i1 : in  unsigned(15 downto 0);
i2 : in  unsigned(15 downto 0);
o1 : out unsigned(0 downto 0);
o2 : out unsigned(0 downto 0);
o3 : out unsigned(0 downto 0);
o4 : out unsigned(0 downto 0);
o5 : out unsigned(0 downto 0);
o6 : out unsigned(5 downto 0);
o7 : out unsigned(21 downto 0));
end component cf_fp_mul_p_5_10_24;
component cf_fp_mul_p_5_10_3 is
port (
clock_c : in std_logic;
i1 : in  unsigned(0 downto 0);
i2 : in  unsigned(0 downto 0);
i3 : in  unsigned(0 downto 0);
i4 : in  unsigned(0 downto 0);
i5 : in  unsigned(0 downto 0);
i6 : in  unsigned(0 downto 0);
i7 : in  unsigned(0 downto 0);
i8 : in  unsigned(5 downto 0);
i9 : in  unsigned(20 downto 0);
o1 : out unsigned(0 downto 0);
o2 : out unsigned(0 downto 0);
o3 : out unsigned(0 downto 0);
o4 : out unsigned(0 downto 0);
o5 : out unsigned(0 downto 0);
o6 : out unsigned(5 downto 0);
o7 : out unsigned(10 downto 0));
end component cf_fp_mul_p_5_10_3;
begin
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n1 <= "0000000000000000";
    elsif i1 = "1" then
      n1 <= i3;
    end if;
  end if;
end process;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n2 <= "0000000000000000";
    elsif i1 = "1" then
      n2 <= i4;
    end if;
  end if;
end process;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n3 <= "0";
    elsif i1 = "1" then
      n3 <= s26_1;
    end if;
  end if;
end process;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n4 <= "0";
    elsif i1 = "1" then
      n4 <= s26_2;
    end if;
  end if;
end process;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n5 <= "0";
    elsif i1 = "1" then
      n5 <= s26_3;
    end if;
  end if;
end process;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n6 <= "0";
    elsif i1 = "1" then
      n6 <= s26_4;
    end if;
  end if;
end process;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n7 <= "0";
    elsif i1 = "1" then
      n7 <= s26_5;
    end if;
  end if;
end process;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n8 <= "000000";
    elsif i1 = "1" then
      n8 <= s26_6;
    end if;
  end if;
end process;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n9 <= "0000000000000000000000";
    elsif i1 = "1" then
      n9 <= s26_7;
    end if;
  end if;
end process;
n10 <= n9(21 downto 21);
n11 <= "000001";
n12 <= n8 + n11;
n13 <= n12 when n10 = "1" else n8;
n14 <= n9(21 downto 21) &
  n9(20 downto 20) &
  n9(19 downto 19) &
  n9(18 downto 18) &
  n9(17 downto 17) &
  n9(16 downto 16) &
  n9(15 downto 15) &
  n9(14 downto 14) &
  n9(13 downto 13) &
  n9(12 downto 12) &
  n9(11 downto 11) &
  n9(10 downto 10) &
  n9(9 downto 9) &
  n9(8 downto 8) &
  n9(7 downto 7) &
  n9(6 downto 6) &
  n9(5 downto 5) &
  n9(4 downto 4) &
  n9(3 downto 3) &
  n9(2 downto 2) &
  n9(1 downto 1);
n15 <= n9(20 downto 20) &
  n9(19 downto 19) &
  n9(18 downto 18) &
  n9(17 downto 17) &
  n9(16 downto 16) &
  n9(15 downto 15) &
  n9(14 downto 14) &
  n9(13 downto 13) &
  n9(12 downto 12) &
  n9(11 downto 11) &
  n9(10 downto 10) &
  n9(9 downto 9) &
  n9(8 downto 8) &
  n9(7 downto 7) &
  n9(6 downto 6) &
  n9(5 downto 5) &
  n9(4 downto 4) &
  n9(3 downto 3) &
  n9(2 downto 2) &
  n9(1 downto 1) &
  n9(0 downto 0);
n16 <= n14 when n10 = "1" else n15;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n17 <= "0";
    elsif i1 = "1" then
      n17 <= n3;
    end if;
  end if;
end process;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n18 <= "0";
    elsif i1 = "1" then
      n18 <= n4;
    end if;
  end if;
end process;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n19 <= "0";
    elsif i1 = "1" then
      n19 <= n5;
    end if;
  end if;
end process;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n20 <= "0";
    elsif i1 = "1" then
      n20 <= n6;
    end if;
  end if;
end process;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n21 <= "0";
    elsif i1 = "1" then
      n21 <= n7;
    end if;
  end if;
end process;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n22 <= "000000";
    elsif i1 = "1" then
      n22 <= n13;
    end if;
  end if;
end process;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n23 <= "000000000000000000000";
    elsif i1 = "1" then
      n23 <= n16;
    end if;
  end if;
end process;
process (clock_c) begin
  if rising_edge(clock_c) then
    if i2 = "1" then
      n24 <= "0000000000000000";
    elsif i1 = "1" then
      n24 <= s25_1;
    end if;
  end if;
end process;
s25 : cf_fp_mul_p_5_10_29 port map (s27_1, s27_2, s27_3, s27_4, s27_5, s27_6, s27_7, s25_1);
s26 : cf_fp_mul_p_5_10_24 port map (n1, n2, s26_1, s26_2, s26_3, s26_4, s26_5, s26_6, s26_7);
s27 : cf_fp_mul_p_5_10_3 port map (clock_c, i1, i2, n17, n18, n19, n20, n21, n22, n23, s27_1, s27_2, s27_3, s27_4, s27_5, s27_6, s27_7);
o1 <= n24;
end architecture rtl;

library ieee;
use ieee.std_logic_1164.all;
use ieee.numeric_std.all;
entity cf_fp_mul_p_5_10_1 is
port (
clock_c : in std_logic;
i1 : in  unsigned(15 downto 0);
i2 : in  unsigned(15 downto 0);
o1 : out unsigned(15 downto 0));
end entity cf_fp_mul_p_5_10_1;
architecture rtl of cf_fp_mul_p_5_10_1 is
signal n1 : unsigned(0 downto 0);
signal n2 : unsigned(0 downto 0);
signal s3_1 : unsigned(15 downto 0);
component cf_fp_mul_p_5_10_2 is
port (
clock_c : in std_logic;
i1 : in  unsigned(0 downto 0);
i2 : in  unsigned(0 downto 0);
i3 : in  unsigned(15 downto 0);
i4 : in  unsigned(15 downto 0);
o1 : out unsigned(15 downto 0));
end component cf_fp_mul_p_5_10_2;
begin
n1 <= "1";
n2 <= "0";
s3 : cf_fp_mul_p_5_10_2 port map (clock_c, n1, n2, i1, i2, s3_1);
o1 <= s3_1;
end architecture rtl;

library ieee;
use ieee.std_logic_1164.all;
use ieee.numeric_std.all;
entity cf_fp_mul_p_5_10 is
port(
signal clock_c : in std_logic;
signal a_i : in unsigned(15 downto 0);
signal b_i : in unsigned(15 downto 0);
signal x_o : out unsigned(15 downto 0));
end entity cf_fp_mul_p_5_10;
architecture rtl of cf_fp_mul_p_5_10 is
component cf_fp_mul_p_5_10_1 is
port (
clock_c : in std_logic;
i1 : in  unsigned(15 downto 0);
i2 : in  unsigned(15 downto 0);
o1 : out unsigned(15 downto 0));
end component cf_fp_mul_p_5_10_1;
signal n1 : unsigned(15 downto 0);
begin
s1 : cf_fp_mul_p_5_10_1 port map (clock_c, a_i, b_i, n1);
x_o <= n1;
end architecture rtl;


